@@ -89,6 +89,15 @@ static inline gui_tool_t gui_toolbox_get_selected_tool ( gui_toolbox_t *this_ );
  */
 void gui_toolbox_set_selected_tool ( gui_toolbox_t *this_, gui_tool_t tool );
 
+/*!
+ *  \brief sets the selected tool and focuses on a diagram
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param tool tool to be selected
+ *  \param focused_diagram id of the diagram to show or DATA_ID_VOID for root diagram
+ */
+void gui_toolbox_set_selected_tool_and_focus ( gui_toolbox_t *this_, gui_tool_t tool, data_id_t focused_diagram );
+
 /*!
  *  \brief callback that informs that the tool button was pressed
  */
@@ -169,6 +178,13 @@ void gui_toolbox_redo_btn_callback( GtkWidget* button, gpointer data );
  */
 gboolean gui_toolbox_redo_shortcut_callback( GtkWidget* widget, GVariant* args, gpointer user_data );
 
+/*!
+ *  \brief searches a suitable diagram to show the changes
+ */
+void gui_toolbox_private_show_changes( gui_toolbox_t *this_,
+                                       ctrl_undo_redo_iterator_t *action_iterator
+                                     );
+
 /*!
  *  \brief notifies the listeners
  *
@@ -227,7 +243,7 @@ void gui_toolbox_private_toggle_display_flag_in_set( gui_toolbox_t *this_,
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
