@@ -5,11 +5,11 @@
 #include "gui_attribute_type_of_diagram.h"
 #include "gui_attribute_type_of_feature.h"
 #include "gui_attribute_type_of_relationship.h"
-#include "draw/draw_stereotype_image.h"
+#include "draw/draw_stereotype_icon.h"
 #include "u8/u8_trace.h"
 #include "ctrl_simple_changer.h"
-#include "data_table.h"
-#include "data_id.h"
+#include "entity/data_table.h"
+#include "entity/data_id.h"
 #include "utf8stringbuf/utf8string.h"
 #include <gtk/gtk.h>
 #include <stdbool.h>
@@ -1251,15 +1251,15 @@ void gui_attributes_editor_private_description_commit_changes ( gui_attributes_e
                 {
                     geometry_rectangle_t view_rect;
                     u8_error_info_t svg_err_info;
-                    draw_stereotype_image_t svg_parser;
-                    draw_stereotype_image_init( &svg_parser );
+                    draw_stereotype_icon_t svg_parser;
+                    draw_stereotype_icon_init( &svg_parser );
                     const u8_error_t svg_err
-                        = draw_stereotype_image_parse_svg_xml( &svg_parser,
-                                                               text,  /* drawing_directives */
-                                                               &view_rect,
-                                                               &svg_err_info
-                                                             );
-                    draw_stereotype_image_destroy( &svg_parser );
+                        = draw_stereotype_icon_parse_svg_xml( &svg_parser,
+                                                              text,  /* drawing_directives */
+                                                              &view_rect,
+                                                              &svg_err_info
+                                                            );
+                    draw_stereotype_icon_destroy( &svg_parser );
                     if ( svg_err == U8_ERROR_NOT_FOUND )
                     {
                         U8_TRACE_INFO( "the stereotype has no image." );
@@ -1361,7 +1361,7 @@ void gui_attributes_editor_private_id_update_view ( gui_attributes_editor_t *thi
 
     char data_id_string_buf[DATA_ID_MAX_UTF8STRING_SIZE];
     utf8stringbuf_t data_id_string = UTF8STRINGBUF( data_id_string_buf );
-    utf8stringbuf_clear( data_id_string );
+    utf8stringbuf_clear( &data_id_string );
     if ( data_id_is_valid( &((*this_).selected_object_id) ) )
     {
         utf8error_t str_err = data_id_to_utf8stringbuf ( &((*this_).selected_object_id), data_id_string );
@@ -1370,7 +1370,7 @@ void gui_attributes_editor_private_id_update_view ( gui_attributes_editor_t *thi
             U8_LOG_ERROR_HEX( "data_id_to_utf8stringbuf failed:", str_err );
         }
     }
-    gtk_label_set_text ( id_widget, utf8stringbuf_get_string( data_id_string ) );
+    gtk_label_set_text ( id_widget, utf8stringbuf_get_string( &data_id_string ) );
 
     U8_TRACE_END();
 }
@@ -1786,7 +1786,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
