@@ -15,12 +15,12 @@
 #include "storage/data_database_reader.h"
 #include "storage/data_database.h"
 #include "storage/data_change_message.h"
-#include "data_classifier.h"
-#include "data_diagram.h"
-#include "data_feature.h"
-#include "data_relationship.h"
+#include "entity/data_classifier.h"
+#include "entity/data_diagram.h"
+#include "entity/data_feature.h"
+#include "entity/data_relationship.h"
 #include "ctrl_controller.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include <gtk/gtk.h>
 
 /*!
@@ -281,7 +281,7 @@ void gui_attributes_editor_private_description_update_view ( gui_attributes_edit
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
