@@ -253,7 +253,7 @@ void gui_file_export_dialog_response_callback( GtkDialog *dialog, gint response_
                     gui_simple_message_to_user_show_message_with_names_and_stat( (*this_).message_to_user,
                                                                                  GUI_SIMPLE_MESSAGE_TYPE_INFO,
                                                                                  GUI_SIMPLE_MESSAGE_CONTENT_EXPORT_FINISHED,
-                                                                                 utf8stringbuf_get_string( temp_fileformat ),
+                                                                                 utf8stringbuf_get_string( &temp_fileformat ),
                                                                                  &export_stat
                                                                                );
 
@@ -375,7 +375,7 @@ void gui_file_export_dialog_async_ready_callback( GObject* source_object,
                 gui_simple_message_to_user_show_message_with_names_and_stat( (*this_).message_to_user,
                                                                              GUI_SIMPLE_MESSAGE_TYPE_INFO,
                                                                              GUI_SIMPLE_MESSAGE_CONTENT_EXPORT_FINISHED,
-                                                                             utf8stringbuf_get_string( temp_fileformat ),
+                                                                             utf8stringbuf_get_string( &temp_fileformat ),
                                                                              &export_stat
                                                                            );
 
@@ -403,7 +403,7 @@ void gui_file_export_dialog_async_ready_callback( GObject* source_object,
 
 
 /*
-Copyright 2019-2024 Andreas Warnke
+Copyright 2019-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
