@@ -17,8 +17,10 @@
 #include "attributes/gui_attributes_editor.h"
 #include "gui_file_use_db_dialog.h"
 #include "gui_file_export_dialog.h"
+#include "gui_file_action.h"
 #include "gui_search_request.h"
 #include "gui_search_runner.h"
+#include "wrap/gui_button.h"
 #include "attributes/gui_attribute_type_of_classifier.h"
 #include "attributes/gui_attribute_type_of_diagram.h"
 #include "attributes/gui_attribute_type_of_feature.h"
@@ -26,10 +28,10 @@
 #include "io_data_file.h"
 #include "storage/data_change_message.h"
 #include "ctrl_controller.h"
-#include "data_diagram_type.h"
-#include "data_classifier_type.h"
-#include "data_feature_type.h"
-#include "data_relationship_type.h"
+#include "entity/data_diagram_type.h"
+#include "entity/data_classifier_type.h"
+#include "entity/data_feature_type.h"
+#include "entity/data_relationship_type.h"
 #include "observer/observer.h"
 #include <gtk/gtk.h>
 
@@ -44,12 +46,11 @@ struct gui_main_window_struct {
     gui_attributes_editor_t attributes_editor;  /*!<  own instance of gui_attributes_editor_t */
     observer_t *window_close_observer;  /*!< pointer to external observer_t listener object */
     observer_t *window_open_observer;  /*!< pointer to external observer_t listener object */
+    gui_file_action_t file_action;  /*!<  own instance of gui_file_action_t */
     gui_file_use_db_dialog_t file_use_db_dialog;  /*!<  own instance of gui_file_use_db_dialog_t */
     gui_file_export_dialog_t file_export_dialog;  /*!<  own instance of gui_file_export_dialog_t */
     io_data_file_t *data_file;  /*!< pointer to external data_file */
-#ifndef NDEBUG
-    ctrl_controller_t *controller;  /*!< pointer to external controller, which can test the database in debug mode */
-#endif  /* not NDEBUG */
+    const gui_resources_t *resources;  /*!< pointer to external resource provider */
 
     GtkWidget *window;
     GtkWidget *main_stack_column;
@@ -59,50 +60,32 @@ struct gui_main_window_struct {
 
     GtkWidget *tool_row;
 
-    GtkWidget *file_new_db_icon;
-    GtkButton *file_new_db;
-    GtkWidget *file_use_db_icon;
-    GtkButton *file_use_db;
-    GtkWidget *file_save_icon;
-    GtkWidget *file_save_button;
-    GtkWidget *file_export_icon;
-    GtkButton *file_export;
+    gui_button_t file_new;
+    gui_button_t file_open;
+    gui_button_t file_save;
+    gui_button_t file_export;
 
     GtkWidget *tool_sect_1_icon;
 
-    GtkWidget *view_new_window_icon;
-    GtkButton *view_new_window;
-    GtkWidget *view_navigate_icon;
-    GtkWidget *view_navigate;
-    GtkWidget *view_edit_icon;
-    GtkWidget *view_edit;
-    GtkWidget *view_create_icon;
-    GtkWidget *view_create;
-    GtkWidget *view_search_icon;
-    GtkWidget *view_search;
+    gui_button_t view_new_window;
+    gui_button_t view_navigate;
+    gui_button_t view_edit;
+    gui_button_t view_create;
+    gui_button_t view_search;
 
     GtkWidget *tool_sect_2_icon;
 
-    GtkWidget *edit_undo_icon;
-    GtkButton *edit_undo;
-    GtkWidget *edit_redo_icon;
-    GtkButton *edit_redo;
-    GtkWidget *edit_cut_icon;
-    GtkButton *edit_cut;
-    GtkWidget *edit_copy_icon;
-    GtkButton *edit_copy;
-    GtkWidget *edit_paste_icon;
-    GtkButton *edit_paste;
-    GtkWidget *edit_delete_icon;
-    GtkButton *edit_delete;
-    GtkWidget *edit_instantiate_icon;
-    GtkButton *edit_instantiate;
-    GtkWidget *edit_highlight_icon;
-    GtkButton *edit_highlight;
-    GtkWidget *edit_reset_icon;
-    GtkButton *edit_reset;
-    GtkWidget *tool_about_icon;
-    GtkButton *tool_about;
+    gui_button_t edit_undo;
+    gui_button_t edit_redo;
+    gui_button_t edit_cut;
+    gui_button_t edit_copy;
+    gui_button_t edit_paste;
+    gui_button_t edit_delete;
+    gui_button_t edit_instantiate;
+    gui_button_t edit_highlight;
+    gui_button_t edit_reset;
+
+    gui_button_t help_about;
 
     GtkShortcutController *keyboard_shortcut_ctrl;
 
@@ -163,7 +146,7 @@ typedef struct gui_main_window_struct gui_main_window_t;
  *  \param controller pointer to a controller object which can modify the database
  *  \param data_file pointer to a data_file object
  *  \param db_reader pointer to a database reader object
- *  \param res pointer to a resource provider
+ *  \param resources pointer to a resource provider
  *  \param gtk_app the gtk application object
  *  \param window_close_observer observer for a button press on the close window button
  *  \param window_open_observer observer for a button press on the open window button
@@ -172,7 +155,7 @@ void gui_main_window_init( gui_main_window_t *this_,
                            ctrl_controller_t *controller,
                            io_data_file_t *data_file,
                            data_database_reader_t *db_reader,
-                           gui_resources_t *res,
+                           gui_resources_t *resources,
                            GtkApplication *gtk_app,
                            observer_t *window_close_observer,
                            observer_t *window_open_observer
@@ -189,34 +172,30 @@ void gui_main_window_destroy( gui_main_window_t *this_ );
  *  \brief initializes the widgets that belong to the toolbox group at the top of the main window
  *
  *  \param this_ pointer to own object attributes
- *  \param res pointer to a resource provider
  */
-void gui_main_window_private_init_toolbox( gui_main_window_t *this_, gui_resources_t *res );
+void gui_main_window_private_init_toolbox( gui_main_window_t *this_ );
 
 /*!
  *  \brief initializes the widgets that belong to the attributes editor group at the right of the main window
  *
  *  \param this_ pointer to own object attributes
- *  \param res pointer to a resource provider
  */
-void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_, gui_resources_t *res );
+void gui_main_window_private_init_attributes_editor( gui_main_window_t *this_ );
 
 /*!
  *  \brief initializes the widgets that belong to the simple message to user group at the bottom of the main window
  *
  *  \param this_ pointer to own object attributes
- *  \param res pointer to a resource provider
  */
-void gui_main_window_private_init_simple_message_to_user( gui_main_window_t *this_, gui_resources_t *res );
+void gui_main_window_private_init_simple_message_to_user( gui_main_window_t *this_ );
 
 /*!
  *  \brief initializes the widgets that belong to the sketch area group at the center of the main window,
  *         including the search bar
  *
  *  \param this_ pointer to own object attributes
- *  \param res pointer to a resource provider
  */
-void gui_main_window_private_init_search_and_sketch_area( gui_main_window_t *this_, gui_resources_t *res );
+void gui_main_window_private_init_search_and_sketch_area( gui_main_window_t *this_ );
 
 /*!
  *  \brief callback that is executed when the main window is destroyed
@@ -270,11 +249,16 @@ void gui_main_window_about_btn_callback( GtkWidget* button, gpointer data );
  */
 void gui_main_window_data_changed_callback( GtkWidget *window, data_change_message_t *msg, gpointer user_data );
 
+/*!
+ *  \brief callback that informs that the window was activated or dropped-to-back
+ */
+void gui_main_window_state_callback( GtkWidget* window, GtkStateFlags old_flags, gpointer user_data );
+
 #endif  /* GUI_MAIN_WINDOW_H */
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
