@@ -11,7 +11,7 @@
 #include "gui_tool.h"
 #include "gui_search_runner.h"
 #include "gui_marked_set.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include "storage/data_change_message.h"
 #include <gtk/gtk.h>
 
@@ -109,7 +109,7 @@ void gui_search_request_data_changed_callback( GtkWidget *widget, data_change_me
 
 
 /*
-Copyright 2019-2024 Andreas Warnke
+Copyright 2019-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
