@@ -13,17 +13,17 @@ static bool gui_toolbox_glib_signal_initialized = false;
 static guint gui_toolbox_glib_signal_id = 0;
 const char *GUI_TOOLBOX_GLIB_SIGNAL_NAME = "cfu_tool_changed";
 
-void gui_toolbox_init ( gui_toolbox_t *this_,
-                        GtkWidget *toolbar,
-                        GtkWidget *tool_navigate,
-                        GtkWidget *tool_edit,
-                        GtkWidget *tool_create,
-                        GtkWidget *tool_search,
-                        GdkClipboard *gtk_clipboard,
-                        gui_marked_set_t *marker,
-                        gui_simple_message_to_user_t *message_to_user,
-                        data_database_reader_t *db_reader,
-                        ctrl_controller_t *controller )
+void gui_toolbox_init( gui_toolbox_t *this_,
+                       GtkWidget *toolbar,
+                       GtkWidget *tool_navigate,
+                       GtkWidget *tool_edit,
+                       GtkWidget *tool_create,
+                       GtkWidget *tool_search,
+                       GdkClipboard *gtk_clipboard,
+                       gui_marked_set_t *marker,
+                       gui_simple_message_to_user_t *message_to_user,
+                       data_database_reader_t *db_reader,
+                       ctrl_controller_t *controller )
 {
     U8_TRACE_BEGIN();
     assert( NULL != tool_navigate );
@@ -47,17 +47,18 @@ void gui_toolbox_init ( gui_toolbox_t *this_,
     (*this_).tool_create = tool_create;
     (*this_).tool_search = tool_search;
 
-    gui_clipboard_init ( &((*this_).clipboard),
-                         gtk_clipboard,
-                         message_to_user,
-                         db_reader,
-                         controller
-                       );
+    gui_clipboard_init( &((*this_).clipboard),
+                        gtk_clipboard,
+                        this_,
+                        message_to_user,
+                        db_reader,
+                        controller
+                      );
 
     /* define a new signal */
     if ( ! gui_toolbox_glib_signal_initialized )
     {
-        gui_toolbox_glib_signal_id = g_signal_new (
+        gui_toolbox_glib_signal_id = g_signal_new(
             GUI_TOOLBOX_GLIB_SIGNAL_NAME,
             G_TYPE_OBJECT,
             G_SIGNAL_RUN_FIRST,
@@ -76,11 +77,11 @@ void gui_toolbox_init ( gui_toolbox_t *this_,
     U8_TRACE_END();
 }
 
-void gui_toolbox_destroy ( gui_toolbox_t *this_ )
+void gui_toolbox_destroy( gui_toolbox_t *this_ )
 {
     U8_TRACE_BEGIN();
 
-    gui_clipboard_destroy ( &((*this_).clipboard) );
+    gui_clipboard_destroy( &((*this_).clipboard) );
 
     (*this_).db_reader = NULL;
     (*this_).controller = NULL;
@@ -97,6 +98,8 @@ void gui_toolbox_destroy ( gui_toolbox_t *this_ )
 
 void gui_toolbox_set_selected_tool( gui_toolbox_t *this_, gui_tool_t tool )
 {
+    U8_TRACE_BEGIN();
+
     switch ( tool )
     {
         case GUI_TOOL_NAVIGATE:
@@ -141,6 +144,28 @@ void gui_toolbox_set_selected_tool( gui_toolbox_t *this_, gui_tool_t tool )
         }
         break;
     }
+
+    U8_TRACE_END();
+}
+
+void gui_toolbox_set_selected_tool_and_focus ( gui_toolbox_t *this_, gui_tool_t tool, data_id_t focused_diagram )
+{
+    U8_TRACE_BEGIN();
+
+    /* switch tool */
+    gui_toolbox_set_selected_tool( this_, tool );
+
+    const data_id_t current_focus = gui_marked_set_get_focused_diagram( (*this_).marker );
+    if ( ! data_id_equals_or_both_void( &focused_diagram, &current_focus ) )
+    {
+        /* clear selected set (no notification) */
+        gui_marked_set_clear_selected_set( (*this_).marker );
+
+        /* request to load the diagram to focus on */
+        gui_marked_set_request_focused_diagram( (*this_).marker, focused_diagram );
+    }
+
+    U8_TRACE_END();
 }
 
 void gui_toolbox_navigate_btn_callback( GtkWidget* button, gpointer data )
@@ -364,9 +389,11 @@ void gui_toolbox_paste( gui_toolbox_t *this_ )
     const data_id_t destination_diagram_id = gui_marked_set_get_focused_diagram( (*this_).marker );
     if ( data_id_is_valid( &destination_diagram_id ) )
     {
-        const data_row_id_t dest_diagram_row_id = data_id_get_row_id( &destination_diagram_id );
+        const data_row_t dest_diagram_row_id = data_id_get_row_id( &destination_diagram_id );
         gui_clipboard_request_clipboard_text( &((*this_).clipboard), dest_diagram_row_id );
 
+        /* this call triggers a callback later to gui_clipboard_clipboard_text_received_callback */
+
         /* Note: (*this_).message_to_user is updated by (*this_).clipboard already - nothing to do here */
     }
     else
@@ -444,8 +471,8 @@ void gui_toolbox_delete( gui_toolbox_t *this_ )
 }
 
 u8_error_t gui_toolbox_private_delete_set( gui_toolbox_t *this_,
-                                             const data_small_set_t *set_to_be_deleted,
-                                             data_stat_t *io_stat )
+                                           const data_small_set_t *set_to_be_deleted,
+                                           data_stat_t *io_stat )
 {
     U8_TRACE_BEGIN();
     assert( NULL != set_to_be_deleted );
@@ -566,7 +593,7 @@ void gui_toolbox_private_toggle_display_flag_in_set( gui_toolbox_t *this_,
             case DATA_TABLE_DIAGRAMELEMENT:
             {
                 data_diagramelement_t out_diagramelement;
-                data_row_id_t diag_elem_id = data_id_get_row_id( &current_id );
+                data_row_t diag_elem_id = data_id_get_row_id( &current_id );
                 ctrl_diagram_controller_t *diag_ctrl;
                 diag_ctrl = ctrl_controller_get_diagram_control_ptr( (*this_).controller );
 
@@ -666,15 +693,27 @@ void gui_toolbox_undo_btn_callback( GtkWidget* button, gpointer data )
     gui_simple_message_to_user_hide( (*this_).message_to_user );
 
     data_stat_t stat;
-    data_stat_init(&stat);
+    data_stat_init( &stat );
 
     ctrl_err = ctrl_controller_undo( (*this_).controller, &stat );
+
+    /* find a diagram that can show the changes */
+    if ( U8_ERROR_NONE == ctrl_err )
+    {
+        ctrl_undo_redo_iterator_t iter;
+        ctrl_undo_redo_iterator_init_empty( &iter );
+        ctrl_err |= ctrl_controller_get_redo_iterator( (*this_).controller, &iter );
+        gui_toolbox_private_show_changes( this_, &iter );
+        ctrl_undo_redo_iterator_destroy( &iter );
+    }
+
+    /* show error/success message to the user */
     if ( U8_ERROR_INVALID_REQUEST == ctrl_err )
     {
         gui_simple_message_to_user_show_message( (*this_).message_to_user,
                                                  GUI_SIMPLE_MESSAGE_TYPE_WARNING,
                                                  GUI_SIMPLE_MESSAGE_CONTENT_NO_MORE_UNDO
-        );
+                                               );
     }
     else if ( U8_ERROR_ARRAY_BUFFER_EXCEEDED == ctrl_err )
     {
@@ -686,14 +725,14 @@ void gui_toolbox_undo_btn_callback( GtkWidget* button, gpointer data )
     else
     {
         /* success */
-        gui_simple_message_to_user_show_message_with_stat ( (*this_).message_to_user,
-                                                            GUI_SIMPLE_MESSAGE_TYPE_INFO,
-                                                            GUI_SIMPLE_MESSAGE_CONTENT_UNDO,
-                                                            &stat
-                                                          );
+        gui_simple_message_to_user_show_message_with_stat( (*this_).message_to_user,
+                                                           GUI_SIMPLE_MESSAGE_TYPE_INFO,
+                                                           GUI_SIMPLE_MESSAGE_CONTENT_UNDO,
+                                                           &stat
+                                                         );
     }
 
-    data_stat_destroy(&stat);
+    data_stat_destroy( &stat );
 
     U8_TRACE_TIMESTAMP();
     U8_TRACE_END();
@@ -715,9 +754,21 @@ void gui_toolbox_redo_btn_callback( GtkWidget* button, gpointer data )
     gui_simple_message_to_user_hide( (*this_).message_to_user );
 
     data_stat_t stat;
-    data_stat_init(&stat);
+    data_stat_init( &stat );
 
     ctrl_err = ctrl_controller_redo( (*this_).controller, &stat );
+
+    /* find a diagram that can show the changes */
+    if ( U8_ERROR_NONE == ctrl_err )
+    {
+        ctrl_undo_redo_iterator_t iter;
+        ctrl_undo_redo_iterator_init_empty( &iter );
+        ctrl_err |= ctrl_controller_get_undo_iterator( (*this_).controller, &iter );
+        gui_toolbox_private_show_changes( this_, &iter );
+        ctrl_undo_redo_iterator_destroy( &iter );
+    }
+
+    /* show error/success message to the user */
     if ( U8_ERROR_INVALID_REQUEST == ctrl_err )
     {
         gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -728,14 +779,14 @@ void gui_toolbox_redo_btn_callback( GtkWidget* button, gpointer data )
     else
     {
         /* success */
-        gui_simple_message_to_user_show_message_with_stat ( (*this_).message_to_user,
-                                                            GUI_SIMPLE_MESSAGE_TYPE_INFO,
-                                                            GUI_SIMPLE_MESSAGE_CONTENT_REDO,
-                                                            &stat
-                                                          );
+        gui_simple_message_to_user_show_message_with_stat( (*this_).message_to_user,
+                                                           GUI_SIMPLE_MESSAGE_TYPE_INFO,
+                                                           GUI_SIMPLE_MESSAGE_CONTENT_REDO,
+                                                           &stat
+                                                         );
     }
 
-    data_stat_destroy(&stat);
+    data_stat_destroy( &stat );
 
     U8_TRACE_TIMESTAMP();
     U8_TRACE_END();
@@ -750,6 +801,176 @@ gboolean gui_toolbox_redo_shortcut_callback( GtkWidget* widget, GVariant* args,
     return TRUE;
 }
 
+void gui_toolbox_private_show_changes( gui_toolbox_t *this_,
+                                       ctrl_undo_redo_iterator_t *action_iterator )
+{
+    U8_TRACE_BEGIN();
+    data_id_t display_diag_nav = DATA_ID_VOID;  /* display this diagram in navigation mode, prio 1 */
+    data_id_t display_diag_edit = DATA_ID_VOID;  /* display this diagram in edit mode, prio 2 */
+    data_id_t display_classifier = DATA_ID_VOID;  /* display this classifier somehow, prio 3 */
+
+    while( ctrl_undo_redo_iterator_has_next( action_iterator ) )
+    {
+        const ctrl_undo_redo_entry_t *const probe = ctrl_undo_redo_iterator_next( action_iterator );
+
+        switch( ctrl_undo_redo_entry_get_action_type( probe ) )
+        {
+            case CTRL_UNDO_REDO_ENTRY_TYPE_DELETE_DIAGRAM:
+            {
+                const data_diagram_t *const diag
+                    = ctrl_undo_redo_entry_get_diagram_before_action_const( probe );
+                assert( data_diagram_is_valid( diag ) );
+                display_diag_nav = data_diagram_get_parent_data_id( diag );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_CREATE_DIAGRAM:
+            {
+                const data_diagram_t *const diag
+                    = ctrl_undo_redo_entry_get_diagram_after_action_const( probe );
+                assert( data_diagram_is_valid( diag ) );
+                display_diag_nav = data_diagram_get_parent_data_id( diag );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_UPDATE_DIAGRAM:
+            {
+                const data_diagram_t *const diag
+                    = ctrl_undo_redo_entry_get_diagram_after_action_const( probe );
+                assert( data_diagram_is_valid( diag ) );
+                display_diag_edit = data_diagram_get_data_id( diag );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_DELETE_DIAGRAMELEMENT:
+            {
+                const data_diagramelement_t *const diagele
+                    = ctrl_undo_redo_entry_get_diagramelement_before_action_const( probe );
+                assert( data_diagramelement_is_valid( diagele ) );
+                display_diag_edit = data_diagramelement_get_diagram_data_id( diagele );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_CREATE_DIAGRAMELEMENT:  /* ... or ... */
+            case CTRL_UNDO_REDO_ENTRY_TYPE_UPDATE_DIAGRAMELEMENT:
+            {
+                const data_diagramelement_t *const diagele
+                    = ctrl_undo_redo_entry_get_diagramelement_after_action_const( probe );
+                assert( data_diagramelement_is_valid( diagele ) );
+                display_diag_edit = data_diagramelement_get_diagram_data_id( diagele );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_DELETE_CLASSIFIER:  /* ... or ... */
+            case CTRL_UNDO_REDO_ENTRY_TYPE_CREATE_CLASSIFIER:
+            {
+                /* Nothing to do: When a classifier is created or deleted, also */
+                /* a diagramelement is created or deleted. */
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_UPDATE_CLASSIFIER:
+            {
+                const data_classifier_t *const classifier
+                    = ctrl_undo_redo_entry_get_classifier_after_action_const( probe );
+                assert( data_classifier_is_valid( classifier ) );
+                display_classifier = data_classifier_get_data_id( classifier );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_DELETE_FEATURE:
+            {
+                const data_feature_t *const feature
+                    = ctrl_undo_redo_entry_get_feature_before_action_const( probe );
+                assert( data_feature_is_valid( feature ) );
+                display_classifier = data_feature_get_classifier_data_id( feature );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_UPDATE_FEATURE:  /* ... or ... */
+            case CTRL_UNDO_REDO_ENTRY_TYPE_CREATE_FEATURE:
+            {
+                const data_feature_t *const feature
+                    = ctrl_undo_redo_entry_get_feature_after_action_const( probe );
+                assert( data_feature_is_valid( feature ) );
+                display_classifier = data_feature_get_classifier_data_id( feature );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_DELETE_RELATIONSHIP:
+            {
+                const data_relationship_t *const relationship
+                    = ctrl_undo_redo_entry_get_relationship_before_action_const( probe );
+                assert( data_relationship_is_valid( relationship ) );
+                display_classifier = data_relationship_get_from_classifier_data_id( relationship );
+            }
+            break;
+
+            case CTRL_UNDO_REDO_ENTRY_TYPE_UPDATE_RELATIONSHIP:  /* ... or ... */
+            case CTRL_UNDO_REDO_ENTRY_TYPE_CREATE_RELATIONSHIP:
+            {
+                const data_relationship_t *const relationship
+                    = ctrl_undo_redo_entry_get_relationship_after_action_const( probe );
+                assert( data_relationship_is_valid( relationship ) );
+                display_classifier = data_relationship_get_from_classifier_data_id( relationship );
+            }
+            break;
+
+            default:  /* ... or ... */
+            case CTRL_UNDO_REDO_ENTRY_TYPE_BOUNDARY:
+            {
+                U8_LOG_WARNING( "gui_toolbox_private_show_changes runs into unexpected switch-case." );
+                assert( false );
+            }
+            break;
+        }
+    }
+
+    if ( data_id_is_valid( &display_diag_nav ) )
+    {
+        gui_toolbox_set_selected_tool_and_focus( this_, GUI_TOOL_NAVIGATE, display_diag_nav );
+    }
+    else if ( data_id_is_valid( &display_diag_edit ) )
+    {
+        gui_toolbox_set_selected_tool_and_focus( this_, GUI_TOOL_EDIT, display_diag_edit );
+    }
+    else if ( data_id_is_valid( &display_classifier ) )
+    {
+        /* try to find ANY diagram that MAY show the modified object: */
+        assert( data_id_get_table( &display_classifier ) == DATA_TABLE_CLASSIFIER );
+        data_small_set_t diagram_ids;
+        data_small_set_init( &diagram_ids );
+        const u8_error_t d_err
+            =  data_database_reader_get_diagram_ids_by_classifier_id( (*this_).db_reader,
+                                                                      data_id_get_row_id( &display_classifier ),
+                                                                      &diagram_ids
+                                                                    );
+        if (( d_err == U8_ERROR_NONE )||( d_err == U8_ERROR_ARRAY_BUFFER_EXCEEDED ))
+        {
+            if ( data_small_set_contains( &diagram_ids, gui_marked_set_get_focused_diagram( (*this_).marker ) ) )
+            {
+                /* the right diagram is already shown, just update the tool */
+                gui_toolbox_set_selected_tool( this_, GUI_TOOL_EDIT );
+            }
+            else if ( ! data_small_set_is_empty( &diagram_ids ) )
+            {
+                gui_toolbox_set_selected_tool_and_focus( this_, GUI_TOOL_EDIT, data_small_set_get_id( &diagram_ids, 0 ) );
+            }
+            else
+            {
+                U8_LOG_ANOMALY( "gui_toolbox_private_show_changes found a classifier without a diagram." );
+            }
+        }
+        data_small_set_destroy( &diagram_ids );
+    }
+    else
+    {
+        U8_LOG_ANOMALY( "gui_toolbox_private_show_changes did not find a diagram to show the changes." );
+    }
+
+    U8_TRACE_END();
+}
+
 void gui_toolbox_private_notify_listeners( gui_toolbox_t *this_ )
 {
     U8_TRACE_BEGIN();
@@ -762,7 +983,7 @@ void gui_toolbox_private_notify_listeners( gui_toolbox_t *this_ )
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
