@@ -117,7 +117,7 @@ void gui_sketch_background_draw_introduction( gui_sketch_background_t *this_,
                                                        );
 
     gui_sketch_background_private_draw_icon_and_message( this_,
-                                                         gui_resources_get_file_new_db( (*this_).resources ),
+                                                         gui_resources_get_file_new( (*this_).resources ),
                                                          "To begin, please",
                                                          "create a new database file first.",
                                                          text_area_start+BORDER,
@@ -332,7 +332,7 @@ void gui_sketch_background_private_draw_icon_and_message( gui_sketch_background_
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
