@@ -1,7 +1,6 @@
 /* File: gui_sketch_card_painter.c; Copyright and License: see below */
 
 #include "sketch/gui_sketch_card_painter.h"
-#include "sketch/gui_sketch_snap_state.h"
 #include "u8/u8_trace.h"
 #include <gtk/gtk.h>
 #include <assert.h>
@@ -53,12 +52,12 @@ void gui_sketch_card_painter_draw_overlay( gui_sketch_card_painter_t *this_,
             const data_id_t highlighted = gui_marked_set_get_highlighted( marked_objects );
             const layout_subelement_kind_t highlighted_kind = gui_marked_set_get_highlighted_kind( marked_objects );
             gui_sketch_card_painter_private_draw_create_mode( this_,
-                                                         drag_state,
-                                                         card_under_mouse,
-                                                         data_id_get_table(&highlighted),
-                                                         highlighted_kind,
-                                                         cr
-                                                       );
+                                                              drag_state,
+                                                              card_under_mouse,
+                                                              data_id_get_table(&highlighted),
+                                                              highlighted_kind,
+                                                              cr
+                                                            );
         }
         break;
 
@@ -89,6 +88,11 @@ void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *
 
     if ( gui_sketch_drag_state_is_dragging ( drag_state ) )
     {
+        const data_full_id_t *const dragged_object
+            = gui_sketch_drag_state_get_dragged_object_const( drag_state );
+        const data_id_t *const dragged_primary = data_full_id_get_primary_id_const( dragged_object );
+        const bool dragging_classifier = ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( dragged_primary ) );
+
         if ( NULL != card_under_mouse )
         {
             const data_diagram_t *diag = gui_sketch_card_get_diagram_const ( card_under_mouse );
@@ -98,16 +102,15 @@ void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *
                 && ( diag_type != DATA_DIAGRAM_TYPE_UML_TIMING_DIAGRAM )
                 && ( diag_type != DATA_DIAGRAM_TYPE_LIST ));
 
-            if ( draw_2d_diagram )
+            if ( draw_2d_diagram && dragging_classifier )
             {
                 /* draw grid line crossings */
                 gui_sketch_card_painter_private_draw_grid( this_, card_under_mouse, cr );
 
-                /* draw snap-to-grid indicator */
+                /* draw new grid lines that visualize the order of classifiers */
                 const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
                 const int32_t to_y = gui_sketch_drag_state_get_to_y ( drag_state );
-                const gui_sketch_snap_state_t snapped = gui_sketch_card_is_pos_on_grid ( card_under_mouse, to_x, to_y );
-                gui_sketch_card_painter_private_draw_snap_indicator( this_, card_under_mouse, snapped, to_x, to_y, cr );
+                gui_sketch_card_painter_private_visualize_order( this_, card_under_mouse, to_x, to_y, cr );
             }
         }
     }
@@ -168,9 +171,8 @@ void gui_sketch_card_painter_private_draw_create_mode( gui_sketch_card_painter_t
                 /* draw grid line crossings */
                 gui_sketch_card_painter_private_draw_grid( this_, card_under_mouse, cr );
 
-                /* draw snap-to-grid indicator */
-                const gui_sketch_snap_state_t snapped = gui_sketch_card_is_pos_on_grid( card_under_mouse, to_x, to_y );
-                gui_sketch_card_painter_private_draw_snap_indicator( this_, card_under_mouse, snapped, to_x, to_y, cr );
+                /* draw new grid lines that visualize the order of classifiers */
+                gui_sketch_card_painter_private_visualize_order( this_, card_under_mouse, to_x, to_y, cr );
             }
 
             /* draw boxes and arrow icons */
@@ -410,39 +412,324 @@ void gui_sketch_card_painter_private_draw_grid( gui_sketch_card_painter_t *this_
     U8_TRACE_END();
 }
 
-void gui_sketch_card_painter_private_draw_snap_indicator( gui_sketch_card_painter_t *this_,
-                                                          const gui_sketch_card_t *card_under_mouse,
-                                                          gui_sketch_snap_state_t snapped,
-                                                          int32_t x,
-                                                          int32_t y,
-                                                          cairo_t *cr )
+void gui_sketch_card_painter_private_visualize_order( gui_sketch_card_painter_t *this_,
+                                                      const gui_sketch_card_t *card_under_mouse,
+                                                      int32_t x,
+                                                      int32_t y,
+                                                      cairo_t *cr )
 {
     U8_TRACE_BEGIN();
     assert( NULL != card_under_mouse );
     assert( NULL != cr );
 
-    const GdkRGBA high_color = gui_sketch_style_get_highlight_color( &((*this_).sketch_style) );
-    cairo_set_source_rgba( cr, high_color.red, high_color.green, high_color.blue, high_color.alpha );
-
-    /* draw marker that position snapped to grid */
+    /* fetch input data: subwidget */
     const shape_int_rectangle_t bounds = gui_sketch_card_get_bounds( card_under_mouse );
     const int32_t left = shape_int_rectangle_get_left(&bounds);
     const int32_t top = shape_int_rectangle_get_top(&bounds);
-    const int32_t width = shape_int_rectangle_get_width(&bounds);
-    const int32_t height = shape_int_rectangle_get_height(&bounds);
-    if ( ( snapped & GUI_SKETCH_SNAP_STATE_X ) == GUI_SKETCH_SNAP_STATE_X )
+    const int32_t right = shape_int_rectangle_get_right(&bounds);
+    const int32_t bottom = shape_int_rectangle_get_bottom(&bounds);
+
+    /* fetch input data: grid */
+    const geometry_grid_t *const grid = gui_sketch_card_get_grid_const( card_under_mouse);
+    const geometry_grid_kind_t grid_kind = geometry_grid_get_kind( grid );
+    const double snap_interval = gui_sketch_style_get_snap_to_grid( &((*this_).sketch_style) );
+    const geometry_non_linear_scale_t *const x_scale = geometry_grid_get_x_scale_const( grid );
+    const int32_t order_at_x = geometry_non_linear_scale_get_order( x_scale, (double) x, snap_interval );
+    const geometry_non_linear_scale_t *const y_scale = geometry_grid_get_y_scale_const( grid );
+    const int32_t order_at_y = geometry_non_linear_scale_get_order( y_scale, (double) y, snap_interval );
+
+    /* define own distances */
+    const double gap = 3.0;
+    const double curve_space = 3.0 * gap;
+
+    /* fetch input data: visible set */
+    const layout_visible_set_t *const layout_data = gui_sketch_card_get_visible_set( card_under_mouse );
+    const uint32_t classifiers = layout_visible_set_get_visible_classifier_count( layout_data );
+
+    /* to draw x, follow y from top to bottom */
+    if (( grid_kind == GEOMETRY_GRID_KIND_X )||( grid_kind == GEOMETRY_GRID_KIND_XY ))
     {
-        cairo_rectangle ( cr, x-2, top, 1, height );
-        cairo_fill (cr);
-        cairo_rectangle ( cr, x+2, top, 1, height );
-        cairo_fill (cr);
+        /* order visible set by top y coordinates of classifiers */
+        universal_array_index_sorter_t sorted;
+        universal_array_index_sorter_init( &sorted );
+        for ( uint32_t idx = 0; idx < classifiers; idx ++ )
+        {
+            const layout_visible_classifier_t *const classifier
+                = layout_visible_set_get_visible_classifier_const( layout_data, idx );
+
+            const geometry_rectangle_t *const envelope = layout_visible_classifier_get_envelope_box_const( classifier );
+            const int64_t weight = geometry_rectangle_get_top( envelope );
+            const u8_error_t insert_error = universal_array_index_sorter_insert( &sorted, idx, weight );
+            if ( U8_ERROR_NONE != insert_error )
+            {
+                U8_LOG_WARNING( "not all rectangles are considered for the top-to-bottom line" );
+            }
+        }
+
+        /* process rectangles top to bottom */
+        /* local variables represent 3 points: */
+        /* current_pos_x / current_pos_y : The position where the already drawn line ends */
+        /* planned_pos_x / planned_pos_y : The position that would be the next unless the next loop finds an earlier position */
+        /* draw_to_pos_x / draw_to_pos_y : While drawing, this is a temporary value storing the next current_pos position */
+        double current_pos_x = x;
+        double current_pos_y = top;
+        double planned_pos_x = x;
+        double planned_pos_y = top;  /* the planned next y - may be superseded by the next classifier */
+        cairo_move_to( cr, x, top );
+        const uint32_t count_sorted = universal_array_index_sorter_get_count( &sorted );
+        for ( uint32_t idx_of_idx = 0; idx_of_idx < count_sorted; idx_of_idx ++ )
+        {
+            const uint32_t idx = universal_array_index_sorter_get_array_index( &sorted, idx_of_idx );
+            const layout_visible_classifier_t *const classifier
+                = layout_visible_set_get_visible_classifier_const( layout_data, idx );
+
+            /* skip classifiers which contain others, these are not positioned according to their order value */
+            const uint32_t children = layout_visible_set_count_descendants( layout_data, classifier );
+            if ( children == 0 )
+            {
+                const data_visible_classifier_t *const vis_data = layout_visible_classifier_get_data_const( classifier );
+                const data_classifier_t *const c_data = data_visible_classifier_get_classifier_const( vis_data );
+                const int32_t c_x_order = data_classifier_get_x_order( c_data );
+                const geometry_rectangle_t *const envelope = layout_visible_classifier_get_envelope_box_const( classifier );
+                const double envelope_left = geometry_rectangle_get_left( envelope );
+                const double envelope_right = geometry_rectangle_get_right( envelope );
+                const double envelope_top = geometry_rectangle_get_top( envelope );
+                const double envelope_bottom = geometry_rectangle_get_bottom( envelope );
+                /* if line passes through the classifier, center on symbol, not on envelope */
+                const geometry_rectangle_t *const symbol = layout_visible_classifier_get_symbol_box_const( classifier );
+                const double symbol_center_x = geometry_rectangle_get_center_x( symbol );
+
+                const bool pass_through_center_x = ( c_x_order == order_at_x );
+                const bool pass_on_left = ( c_x_order > order_at_x ) && ( envelope_left < x );
+                const bool pass_on_right = ( c_x_order < order_at_x ) && ( envelope_right > x );
+                const bool ignored = !( pass_through_center_x || pass_on_left || pass_on_right );
+                const double draw_to_pos_y = envelope_top - gap;
+                double draw_to_pos_x = x;
+                if ( pass_through_center_x )
+                {
+                    draw_to_pos_x = symbol_center_x;
+                }
+                if ( pass_on_left )
+                {
+                    draw_to_pos_x = envelope_left - gap;
+                }
+                if ( pass_on_right )
+                {
+                    draw_to_pos_x = envelope_right + gap;
+                }
+                if ( ! ignored )
+                {
+                    /* if planned_pos_x not at x and enough space to draw */
+                    /* 1) a return to x and 2) a comeback to new draw_to_pos_x */
+                    if ( (( planned_pos_x < ( x - 0.001 ) )||( planned_pos_x > ( x + 0.001 ) ))
+                         && ( planned_pos_y + ( 2 * curve_space ) < draw_to_pos_y ) )
+                    {
+                        cairo_line_to( cr, current_pos_x, planned_pos_y );
+                        cairo_curve_to( cr,
+                                        current_pos_x,
+                                        planned_pos_y + curve_space,
+                                        x,
+                                        planned_pos_y,
+                                        x,
+                                        planned_pos_y + curve_space
+                                      );
+                        current_pos_x = x;
+                        current_pos_y = planned_pos_y + curve_space;
+                    }
+
+                    /* if there is enough space to draw a line before drawing a curve to draw_to_pos_x */
+                    if ( ( current_pos_y + curve_space ) < draw_to_pos_y )
+                    {
+                        cairo_line_to( cr, current_pos_x, draw_to_pos_y - curve_space );
+                        current_pos_y = draw_to_pos_y - curve_space;
+                    }
+
+                    /* draw begin of current pass-by */
+                    cairo_curve_to( cr,
+                                    current_pos_x,
+                                    draw_to_pos_y,
+                                    draw_to_pos_x,
+                                    current_pos_y,
+                                    draw_to_pos_x,
+                                    draw_to_pos_y
+                                  );
+                    /* update variables for next loop */
+                    current_pos_x = draw_to_pos_x;
+                    current_pos_y = draw_to_pos_y;
+                    planned_pos_x = current_pos_x;
+                    planned_pos_y = envelope_bottom + gap;
+                }
+            }
+        }
+        /* draw end of last pass-by (if any) */
+        if ( (( planned_pos_x < ( x - 0.001 ) )||( planned_pos_x > ( x + 0.001 ) ))
+            && ( planned_pos_y + ( 1 * curve_space ) < bottom ) )
+        {
+            cairo_line_to( cr, current_pos_x, planned_pos_y );
+            cairo_curve_to( cr,
+                            current_pos_x,
+                            planned_pos_y + curve_space,
+                            x,
+                            planned_pos_y,
+                            x,
+                            planned_pos_y + curve_space
+                          );
+            current_pos_x = x;
+            current_pos_y = planned_pos_y + curve_space;
+        }
+        /* draw to end point and stroke the drawn path */
+        cairo_line_to( cr, current_pos_x, bottom );
+        {
+            double dashes[2];
+            dashes[0] = 2.0 * gap;  /* on segment */
+            dashes[1] = 4.0 * gap;  /* off segment */
+            cairo_set_dash ( cr, dashes, 2, 0.0 );
+        }
+        cairo_stroke( cr );
+        cairo_set_dash( cr, NULL, 0, 0.0 );
     }
-    if ( ( snapped & GUI_SKETCH_SNAP_STATE_Y ) == GUI_SKETCH_SNAP_STATE_Y )
+
+    /* to draw y, follow x from left to right */
+    if (( grid_kind == GEOMETRY_GRID_KIND_Y )||( grid_kind == GEOMETRY_GRID_KIND_XY ))
     {
-        cairo_rectangle ( cr, left, y-2, width, 1 );
-        cairo_fill (cr);
-        cairo_rectangle ( cr, left, y+2, width, 1 );
-        cairo_fill (cr);
+        /* order visible set by left x coordinates of classifiers */
+        universal_array_index_sorter_t sorted;
+        universal_array_index_sorter_init( &sorted );
+        for ( uint32_t idx = 0; idx < classifiers; idx ++ )
+        {
+            const layout_visible_classifier_t *const classifier
+                = layout_visible_set_get_visible_classifier_const( layout_data, idx );
+
+            const geometry_rectangle_t *const envelope = layout_visible_classifier_get_envelope_box_const( classifier );
+            const int64_t weight = geometry_rectangle_get_left( envelope );
+            const u8_error_t insert_error = universal_array_index_sorter_insert( &sorted, idx, weight );
+            if ( U8_ERROR_NONE != insert_error )
+            {
+                U8_LOG_WARNING( "not all rectangles are considered for the left-to-right line" );
+            }
+        }
+
+        /* process rectangles left to right */
+        /* local variables represent 3 points: */
+        /* current_pos_x / current_pos_y : The position where the already drawn line ends */
+        /* planned_pos_x / planned_pos_y : The position that would be the next unless the next loop finds an earlier position */
+        /* draw_to_pos_x / draw_to_pos_y : While drawing, this is a temporary value storing the next current_pos position */
+        double current_pos_x = left;
+        double current_pos_y = y;
+        double planned_pos_x = left;  /* the planned next x - may be superseded by the next classifier */
+        double planned_pos_y = y;
+        cairo_move_to( cr, left, y );
+        const uint32_t count_sorted = universal_array_index_sorter_get_count( &sorted );
+        for ( uint32_t idx_of_idx = 0; idx_of_idx < count_sorted; idx_of_idx ++ )
+        {
+            const uint32_t idx = universal_array_index_sorter_get_array_index( &sorted, idx_of_idx );
+            const layout_visible_classifier_t *const classifier
+                = layout_visible_set_get_visible_classifier_const( layout_data, idx );
+
+            /* skip classifiers which contain others, these are not positioned according to their order value */
+            const uint32_t children = layout_visible_set_count_descendants( layout_data, classifier );
+            if ( children == 0 )
+            {
+                const data_visible_classifier_t *const vis_data = layout_visible_classifier_get_data_const( classifier );
+                const data_classifier_t *const c_data = data_visible_classifier_get_classifier_const( vis_data );
+                const int32_t c_y_order = data_classifier_get_y_order( c_data );
+                const geometry_rectangle_t *const envelope = layout_visible_classifier_get_envelope_box_const( classifier );
+                const double envelope_top = geometry_rectangle_get_top( envelope );
+                const double envelope_bottom = geometry_rectangle_get_bottom( envelope );
+                const double envelope_left = geometry_rectangle_get_left( envelope );
+                const double envelope_right = geometry_rectangle_get_right( envelope );
+                /* if line passes through the classifier, center on symbol, not on envelope */
+                const geometry_rectangle_t *const symbol = layout_visible_classifier_get_symbol_box_const( classifier );
+                const double symbol_center_y = geometry_rectangle_get_center_y( symbol );
+
+                const bool pass_through_center_y = ( c_y_order == order_at_y );
+                const bool pass_on_top = ( c_y_order > order_at_y ) && ( envelope_top < y );
+                const bool pass_on_bottom = ( c_y_order < order_at_y ) && ( envelope_bottom > y );
+                const bool ignored = !( pass_through_center_y || pass_on_top || pass_on_bottom );
+                const double draw_to_pos_x = envelope_left - gap;
+                double draw_to_pos_y = y;
+                if ( pass_through_center_y )
+                {
+                    draw_to_pos_y = symbol_center_y;
+                }
+                if ( pass_on_top )
+                {
+                    draw_to_pos_y = envelope_top - gap;
+                }
+                if ( pass_on_bottom )
+                {
+                    draw_to_pos_y = envelope_bottom + gap;
+                }
+                if ( ! ignored )
+                {
+                    /* if planned_pos_y not at y and enough space to draw */
+                    /* 1) a return to y and 2) a comeback to new draw_to_pos_y */
+                    if ( (( planned_pos_y < ( y - 0.001 ) )||( planned_pos_y > ( y + 0.001 ) ))
+                         && ( planned_pos_x + ( 2 * curve_space ) < draw_to_pos_x ) )
+                    {
+                        cairo_line_to( cr, planned_pos_x, current_pos_y );
+                        cairo_curve_to( cr,
+                                        planned_pos_x + curve_space,
+                                        current_pos_y,
+                                        planned_pos_x,
+                                        y,
+                                        planned_pos_x + curve_space,
+                                        y
+                                      );
+                        current_pos_x = planned_pos_x + curve_space;
+                        current_pos_y = y;
+                    }
+
+                    /* if there is enough space to draw a line before drawing a curve to draw_to_pos_x */
+                    if ( ( current_pos_x + curve_space ) < draw_to_pos_x )
+                    {
+                        cairo_line_to( cr, draw_to_pos_x - curve_space, current_pos_y );
+                        current_pos_x = draw_to_pos_x - curve_space;
+                    }
+
+                    /* draw begin of current pass-by */
+                    cairo_curve_to( cr,
+                                    draw_to_pos_x,
+                                    current_pos_y,
+                                    current_pos_x,
+                                    draw_to_pos_y,
+                                    draw_to_pos_x,
+                                    draw_to_pos_y
+                                  );
+                    /* update variables for next loop */
+                    current_pos_x = draw_to_pos_x;
+                    current_pos_y = draw_to_pos_y;
+                    planned_pos_x = envelope_right + gap;
+                    planned_pos_y = current_pos_y;
+                }
+            }
+        }
+        /* draw end of last pass-by (if any) */
+        if ( (( planned_pos_y < ( y - 0.001 ) )||( planned_pos_y > ( y + 0.001 ) ))
+            && ( planned_pos_x + ( 1 * curve_space ) < right ) )
+        {
+            cairo_line_to( cr, planned_pos_x, current_pos_y );
+            cairo_curve_to( cr,
+                            planned_pos_x + curve_space,
+                            current_pos_y,
+                            planned_pos_x,
+                            y,
+                            planned_pos_x + curve_space,
+                            y
+                          );
+            current_pos_x = planned_pos_x + curve_space;
+            current_pos_y = y;
+        }
+        /* draw to end point and stroke the drawn path */
+        cairo_line_to( cr, right, current_pos_y );
+        {
+            double dashes[2];
+            dashes[0] = 2.0 * gap;  /* on segment */
+            dashes[1] = 4.0 * gap;  /* off segment */
+            cairo_set_dash ( cr, dashes, 2, 0.0 );
+        }
+        cairo_stroke( cr );
+        cairo_set_dash( cr, NULL, 0, 0.0 );
     }
 
     U8_TRACE_END();
@@ -457,6 +744,8 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
     assert( NULL != layouted_set );
     assert( NULL != cr );
     const layout_diagram_t *const layout_diag = layout_visible_set_get_diagram_const( layouted_set );
+    const double label_border = 2.0;  /* additional visible border that just draws a box nicely, without effect for selecting */
+    const double connector_border = (double) gui_sketch_style_get_snap_to_relationship( &((*this_).sketch_style) );
 
     geometry_rectangle_t highlight;
     geometry_rectangle_init_empty( &highlight );
@@ -553,7 +842,7 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
                 case LAYOUT_SUBELEMENT_KIND_LABEL:
                 {
                     geometry_rectangle_replace( &highlight, layout_feature_get_label_box_const( the_feature ) );
-                    geometry_rectangle_expand_4dir( &highlight, 4.0 /* delta_width */, 4.0 /* delta_height */ );
+                    geometry_rectangle_expand_4dir( &highlight, 2.0 * label_border, 2.0 * label_border );
                     gui_sketch_card_painter_private_draw_rect( this_, &highlight, cr );
                 }
                 break;
@@ -562,7 +851,7 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
                 case LAYOUT_SUBELEMENT_KIND_OUTLINE:
                 {
                     geometry_rectangle_replace( &highlight, layout_feature_get_symbol_box_const( the_feature ) );
-                    geometry_rectangle_expand_4dir( &highlight, 4.0 /* delta_width */, 4.0 /* delta_height */ );
+                    geometry_rectangle_expand_4dir( &highlight, 2.0 * label_border, 2.0 * label_border );
                     gui_sketch_card_painter_private_draw_rect( this_, &highlight, cr );
                 }
                 break;
@@ -584,7 +873,7 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
                 case LAYOUT_SUBELEMENT_KIND_LABEL:
                 {
                     geometry_rectangle_replace( &highlight, layout_relationship_get_label_box_const( the_relationship ) );
-                    geometry_rectangle_expand_4dir( &highlight, 4.0 /* delta_width */, 4.0 /* delta_height */ );
+                    geometry_rectangle_expand_4dir( &highlight, 2.0 * label_border, 2.0 * label_border );
                     gui_sketch_card_painter_private_draw_rect( this_, &highlight, cr );
                 }
                 break;
@@ -599,7 +888,7 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
                         segment_src = geometry_connector_get_segment_bounds( relationship_shape,
                                                                              GEOMETRY_CONNECTOR_SEGMENT_SOURCE
                                                                            );
-                        geometry_rectangle_expand_4dir( &segment_src, 6.0 /* delta_width */, 6.0 /* delta_height */ );
+                        geometry_rectangle_expand_4dir( &segment_src, 2.0 * connector_border, 2.0 * connector_border );
                         gui_sketch_card_painter_private_draw_rect( this_, &segment_src, cr );
                     }
                     {
@@ -607,15 +896,15 @@ void gui_sketch_card_painter_private_draw_element_space( const gui_sketch_card_p
                         segment_dst = geometry_connector_get_segment_bounds( relationship_shape,
                                                                              GEOMETRY_CONNECTOR_SEGMENT_DESTINATION
                                                                            );
-                        geometry_rectangle_expand_4dir( &segment_dst, 6.0 /* delta_width */, 6.0 /* delta_height */ );
+                        geometry_rectangle_expand_4dir( &segment_dst, 2.0 * connector_border, 2.0 * connector_border );
                         gui_sketch_card_painter_private_draw_rect( this_, &segment_dst, cr );
                     }
                     {
                         geometry_rectangle_t segment_main;
                         segment_main = geometry_connector_get_segment_bounds( relationship_shape,
-                                                                           GEOMETRY_CONNECTOR_SEGMENT_MAIN
-                                                                         );
-                        geometry_rectangle_expand_4dir( &segment_main, 6.0 /* delta_width */, 6.0 /* delta_height */ );
+                                                                              GEOMETRY_CONNECTOR_SEGMENT_MAIN
+                                                                            );
+                        geometry_rectangle_expand_4dir( &segment_main, 2.0 * connector_border, 2.0 * connector_border );
                         gui_sketch_card_painter_private_draw_rect( this_, &segment_main, cr );
                     }
                 }
@@ -684,7 +973,7 @@ void gui_sketch_card_painter_draw_paper( gui_sketch_card_painter_t *this_,
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
