@@ -100,10 +100,9 @@ void gui_sketch_result_list_private_layout_element ( gui_sketch_result_list_t *t
 
     /* determine icon dimensions */
     {
-        const data_table_t result_table = data_search_result_get_match_table( result );
-        const int result_type = data_search_result_get_match_type( result );
+        const data_type_t result_type = data_search_result_get_match_type( result );
         gui_type_resource_t *const type_data
-            = gui_type_resource_list_get_type ( &((*this_).selector), result_table, result_type );
+            = gui_type_resource_list_get_type ( &((*this_).selector), result_type );
         GdkTexture *const icon = gui_type_resource_get_icon( type_data );
         const double icon_width = gdk_texture_get_width( icon );
         const double icon_height = gdk_texture_get_height( icon );
@@ -277,10 +276,9 @@ void gui_sketch_result_list_private_draw_element( gui_sketch_result_list_t *this
     /* draw the icon */
     {
         /* what to draw */
-        const data_table_t result_table = data_search_result_get_match_table( result );
-        const int result_type = data_search_result_get_match_type( result );
+        const data_type_t result_type = data_search_result_get_match_type( result );
         gui_type_resource_t *const type_data
-            = gui_type_resource_list_get_type ( &((*this_).selector), result_table, result_type );
+            = gui_type_resource_list_get_type ( &((*this_).selector), result_type );
         GdkTexture *const icon = gui_type_resource_get_icon( type_data );
 
         /* where to draw to */
@@ -300,7 +298,7 @@ void gui_sketch_result_list_private_draw_element( gui_sketch_result_list_t *this
 
 
 /*
-Copyright 2018-2024 Andreas Warnke
+Copyright 2018-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
