@@ -4,7 +4,7 @@
 #include "sketch/gui_sketch_nav_tree.h"
 #include "shape/shape_int_rectangle.h"
 #include "gui_resources.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "test_fixture.h"
 #include "test_expect.h"
 #include "test_environment_assert.h"
@@ -506,7 +506,7 @@ static test_case_result_t test_get_object_at_pos_on_2parent_2siblings_diagram( t
 
 
 /*
- * Copyright 2019-2024 Andreas Warnke
+ * Copyright 2019-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
