@@ -2,7 +2,7 @@
 
 #include "document/document_element_writer.h"
 #include "utf8stringbuf/utf8string.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
 #include <stdio.h>
@@ -1829,7 +1829,7 @@ u8_error_t document_element_writer_write_footer( document_element_writer_t *this
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
