@@ -27,8 +27,8 @@ void io_exporter_init ( io_exporter_t *this_,
 
     (*this_).db_reader = db_reader;
 
-    (*this_).temp_filename = utf8stringbuf_init( sizeof((*this_).temp_filename_buf), (*this_).temp_filename_buf );
-    utf8stringbuf_clear( (*this_).temp_filename );
+    (*this_).temp_filename = utf8stringbuf_new( (*this_).temp_filename_buf, sizeof((*this_).temp_filename_buf) );
+    utf8stringbuf_clear( &((*this_).temp_filename) );
 
     U8_TRACE_END();
 }
@@ -58,7 +58,7 @@ u8_error_t io_exporter_export_files( io_exporter_t *this_,
     char temp_filename_buf[48];
     utf8stringbuf_t temp_filename = UTF8STRINGBUF(temp_filename_buf);
     u8_error_t err = io_exporter_private_get_filename( this_, document_file_path, temp_filename );
-    const char *const document_file_name = (err==0) ? utf8stringbuf_get_string(temp_filename) : "document";
+    const char *const document_file_name = (err==0) ? utf8stringbuf_get_string( &temp_filename ) : "document";
 
     if ( NULL != target_folder )
     {
@@ -147,17 +147,35 @@ u8_error_t io_exporter_private_get_filename( io_exporter_t *this_,
     assert ( NULL != path );
     u8_error_t err = U8_ERROR_NONE;
 
-    const unsigned int path_len = utf8string_get_length( path );
-    const int path_suffix = utf8string_find_last_str( path, "." );
-    const int path_start_filename_unix = utf8string_find_last_str( path, "/" );
-    const int path_start_filename_win = utf8string_find_last_str( path, "\\" );
-    const int path_start_filename = u8_i32_max2( path_start_filename_unix, path_start_filename_win );
-    const int start = (( path_start_filename == -1 ) ? 0 : (path_start_filename+1) );
-    const int length = (( path_suffix < start ) ? (path_len-start) : (path_suffix-start) );
-    const utf8stringview_t base_name = UTF8STRINGVIEW( &(path[start]), length );
+    utf8stringview_t path_view = UTF8STRINGVIEW_STR( path );
 
-    err = utf8stringbuf_copy_view( out_base_filename, &base_name );
-    if ( utf8stringbuf_get_length( out_base_filename ) == 0 )
+    utf8stringview_t before_winpath_sep;
+    utf8stringview_t after_winpath_sep;
+    const utf8error_t err_w = utf8stringview_split_at_last_str( &path_view, "\\", &before_winpath_sep, &after_winpath_sep );
+    if ( err_w != UTF8ERROR_SUCCESS )
+    {
+        after_winpath_sep = path_view;
+    }
+    utf8stringview_t before_unixpath_sep;
+    utf8stringview_t after_unixpath_sep;
+    const utf8error_t err_u = utf8stringview_split_at_last_str( &after_winpath_sep, "/", &before_unixpath_sep, &after_unixpath_sep );
+    if ( err_u != UTF8ERROR_SUCCESS )
+    {
+        after_unixpath_sep = after_winpath_sep;
+    }
+    utf8stringview_t before_dot;
+    utf8stringview_t after_dot;
+    const utf8error_t err_d = utf8stringview_split_at_last_str( &after_unixpath_sep, ".", &before_dot, &after_dot );
+    if ( ( err_d != UTF8ERROR_SUCCESS )
+        || ( utf8stringview_get_length( &before_dot ) == 0 )
+        || ( utf8stringview_get_length( &after_dot ) == 0 ) )
+    {
+        /* either no dot found or the filename begins with dot or the filename ends on dot */
+        before_dot = after_unixpath_sep;
+    }
+
+    err = utf8stringbuf_copy_view( &out_base_filename, &before_dot );
+    if ( utf8stringbuf_get_length( &out_base_filename ) == 0 )
     {
         err = U8_ERROR_INPUT_EMPTY;
     }
@@ -177,45 +195,45 @@ u8_error_t io_exporter_private_export_image_files( io_exporter_t *this_,
     assert ( NULL != target_folder );
     assert ( NULL != io_export_stat );
     U8_TRACE_INFO_STR("target_folder:", target_folder );
-    const data_row_id_t diagram_row_id = data_id_get_row_id( &diagram_id );
+    const data_row_t diagram_row_id = data_id_get_row_id( &diagram_id );
     u8_error_t result = U8_ERROR_NONE;
 
     /* draw current diagram */
-    if ( DATA_ROW_ID_VOID != diagram_row_id )
+    if ( DATA_ROW_VOID != diagram_row_id )
     {
         assert( data_id_get_table( &diagram_id ) == DATA_TABLE_DIAGRAM );
 
         /* determine filename */
-        utf8stringbuf_copy_str( (*this_).temp_filename, target_folder );
-        utf8stringbuf_append_str( (*this_).temp_filename, "/" );
-        result |= io_exporter_private_get_filename_for_diagram( this_, diagram_id, utf8stringbuf_get_end( (*this_).temp_filename ) );
+        utf8stringbuf_copy_str( &((*this_).temp_filename), target_folder );
+        utf8stringbuf_append_str( &((*this_).temp_filename), "/" );
+        result |= io_exporter_private_get_filename_for_diagram( this_, diagram_id, utf8stringbuf_get_end( &((*this_).temp_filename) ) );
 
         if ( IO_FILE_FORMAT_SVG == export_type )
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".svg" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".svg" );
         }
         else if ( IO_FILE_FORMAT_PNG == export_type )
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".png" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".png" );
         }
         else if ( IO_FILE_FORMAT_PDF == export_type )
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".pdf" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".pdf" );
         }
         else if ( IO_FILE_FORMAT_PS == export_type )
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".ps" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".ps" );
         }
         else /* IO_FILE_FORMAT_TXT */
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".txt" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".txt" );
         }
-        U8_LOG_EVENT_STR( "exporting diagram to file:", utf8stringbuf_get_string( (*this_).temp_filename ) );
+        U8_LOG_EVENT_STR( "exporting diagram to file:", utf8stringbuf_get_string( &((*this_).temp_filename) ) );
 
         result |= io_exporter_export_image_file( this_,
                                                  diagram_id,
                                                  export_type,
-                                                 utf8stringbuf_get_string( (*this_).temp_filename ),
+                                                 utf8stringbuf_get_string( &((*this_).temp_filename) ),
                                                  io_export_stat
                                                );
     }
@@ -350,60 +368,60 @@ u8_error_t io_exporter_private_export_document_file( io_exporter_t *this_,
     u8_error_t export_err = U8_ERROR_NONE;
 
     /* open file */
-    utf8stringbuf_copy_str( (*this_).temp_filename, target_folder );
-    utf8stringbuf_append_str( (*this_).temp_filename, "/" );
-    utf8stringbuf_append_str( (*this_).temp_filename, document_file_name );
+    utf8stringbuf_copy_str( &((*this_).temp_filename), target_folder );
+    utf8stringbuf_append_str( &((*this_).temp_filename), "/" );
+    utf8stringbuf_append_str( &((*this_).temp_filename), document_file_name );
     switch ( export_type )
     {
         case IO_FILE_FORMAT_DOCBOOK:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".xml" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".xml" );
         }
         break;
 
         case IO_FILE_FORMAT_HTML:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".html" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".html" );
         }
         break;
 
         case IO_FILE_FORMAT_CSS:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".css" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".css" );
         }
         break;
 
         case IO_FILE_FORMAT_JSON:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".json" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".json" );
         }
         break;
 
         case IO_FILE_FORMAT_SCHEMA:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".schema" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".schema" );
         }
         break;
 
         case IO_FILE_FORMAT_XMI2:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".xmi" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".xmi" );
         }
         break;
 
         default:
         {
-            utf8stringbuf_append_str( (*this_).temp_filename, ".unknown_format" );
+            utf8stringbuf_append_str( &((*this_).temp_filename), ".unknown_format" );
             U8_LOG_ERROR("error: unknown_format.");
         }
         break;
     }
-    U8_LOG_EVENT_STR( "exporting diagrams to document file:", utf8stringbuf_get_string( (*this_).temp_filename ) );
+    U8_LOG_EVENT_STR( "exporting diagrams to document file:", utf8stringbuf_get_string( &((*this_).temp_filename) ) );
 
     export_err |= io_exporter_export_document_file( this_,
                                                     export_type,
                                                     document_file_name,
-                                                    utf8stringbuf_get_string( (*this_).temp_filename ),
+                                                    utf8stringbuf_get_string( &((*this_).temp_filename) ),
                                                     io_export_stat
                                                   );
 
@@ -567,11 +585,11 @@ u8_error_t io_exporter_private_export_document_part( io_exporter_t *this_,
 {
     U8_TRACE_BEGIN();
     assert ( NULL != io_export_stat );
-    const data_row_id_t diagram_row_id = data_id_get_row_id( &diagram_id );
+    const data_row_t diagram_row_id = data_id_get_row_id( &diagram_id );
     u8_error_t export_err = U8_ERROR_NONE;
 
     /* write part for current diagram */
-    if ( DATA_ROW_ID_VOID != diagram_row_id )
+    if ( DATA_ROW_VOID != diagram_row_id )
     {
         assert( data_id_get_table( &diagram_id ) == DATA_TABLE_DIAGRAM );
 
@@ -582,7 +600,7 @@ u8_error_t io_exporter_private_export_document_part( io_exporter_t *this_,
         /* write doc part */
         export_err |= io_export_diagram_traversal_begin_and_walk_diagram( &((*this_).temp_diagram_traversal),
                                                                           diagram_id,
-                                                                          utf8stringbuf_get_string( (*this_).temp_filename )
+                                                                          utf8stringbuf_get_string( &((*this_).temp_filename) )
                                                                         );
     }
 
@@ -614,7 +632,7 @@ u8_error_t io_exporter_private_export_document_part( io_exporter_t *this_,
     }
 
     /* end diagram section */
-    if ( DATA_ROW_ID_VOID != diagram_row_id )
+    if ( DATA_ROW_VOID != diagram_row_id )
     {
         /* write doc part */
         export_err |= io_export_diagram_traversal_end_diagram( &((*this_).temp_diagram_traversal), diagram_id );
@@ -631,11 +649,11 @@ u8_error_t io_exporter_private_export_table_of_contents( io_exporter_t *this_,
 {
     U8_TRACE_BEGIN();
     assert ( NULL != format_writer );
-    const data_row_id_t diagram_row_id = data_id_get_row_id( &diagram_id );
+    const data_row_t diagram_row_id = data_id_get_row_id( &diagram_id );
     u8_error_t export_err = U8_ERROR_NONE;
 
     /* write entry for current diagram */
-    if ( DATA_ROW_ID_VOID != diagram_row_id )
+    if ( DATA_ROW_VOID != diagram_row_id )
     {
         assert( data_id_get_table( &diagram_id ) == DATA_TABLE_DIAGRAM );
 
@@ -689,7 +707,7 @@ u8_error_t io_exporter_private_export_table_of_contents( io_exporter_t *this_,
     }
 
     /* end toc entry */
-    if ( DATA_ROW_ID_VOID != diagram_row_id )
+    if ( DATA_ROW_VOID != diagram_row_id )
     {
         export_err |= document_element_writer_end_toc_entry( format_writer );
     }
@@ -705,7 +723,7 @@ u8_error_t io_exporter_private_get_filename_for_diagram( io_exporter_t *this_,
     U8_TRACE_BEGIN();
     assert( data_id_get_table( &diagram_id ) == DATA_TABLE_DIAGRAM );
     u8_error_t result = U8_ERROR_NONE;
-    utf8stringbuf_clear( filename );
+    utf8stringbuf_clear( &filename );
 
     u8_error_t db_err;
     db_err = data_database_reader_get_diagram_by_id ( (*this_).db_reader, data_id_get_row_id( &diagram_id ), &((*this_).temp_diagram) );
@@ -721,7 +739,7 @@ u8_error_t io_exporter_private_get_filename_for_diagram( io_exporter_t *this_,
 
         /* determine filename */
         data_id_to_utf8stringbuf( &diagram_id, filename );
-        utf8stringbuf_append_str( filename, "_" );
+        utf8stringbuf_append_str( &filename, "_" );
         io_exporter_private_append_valid_chars_to_filename( this_, diag_name, filename );
         data_diagram_destroy( &((*this_).temp_diagram) );
     }
@@ -749,27 +767,27 @@ void io_exporter_private_append_valid_chars_to_filename( io_exporter_t *this_,
         }
         else if (( 'A' <= probe ) && ( probe <= 'Z' ))
         {
-            utf8stringbuf_append_char( filename, probe );
+            utf8stringbuf_append_char( &filename, probe );
         }
         else if (( 'a' <= probe ) && ( probe <= 'z' ))
         {
-            utf8stringbuf_append_char( filename, probe );
+            utf8stringbuf_append_char( &filename, probe );
         }
         else if (( '0' <= probe ) && ( probe <= '9' ))
         {
-            utf8stringbuf_append_char( filename, probe );
+            utf8stringbuf_append_char( &filename, probe );
         }
         else if ( '-' == probe )
         {
-            utf8stringbuf_append_char( filename, probe );
+            utf8stringbuf_append_char( &filename, probe );
         }
         else if ( '_' == probe )
         {
-            utf8stringbuf_append_char( filename, probe );
+            utf8stringbuf_append_char( &filename, probe );
         }
         else if ( ' ' == probe )
         {
-            utf8stringbuf_append_char( filename, '_' );
+            utf8stringbuf_append_char( &filename, '_' );
         }
     }
 
@@ -778,7 +796,7 @@ void io_exporter_private_append_valid_chars_to_filename( io_exporter_t *this_,
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
