@@ -20,7 +20,7 @@ static test_case_result_t test_md_plain_mixed( test_fixture_t *fix );
 static test_case_result_t test_valid_links( test_fixture_t *fix );
 static test_case_result_t test_invalid_links( test_fixture_t *fix );
 
-static data_row_id_t create_root_diag( ctrl_controller_t *controller );  /* helper function */
+static data_row_t create_root_diag( ctrl_controller_t *controller );  /* helper function */
 
 test_suite_t io_md_writer_test_get_suite(void)
 {
@@ -93,7 +93,7 @@ static void tear_down( test_fixture_t *fix )
     data_database_destroy( &((*fix).database) );
 }
 
-static data_row_id_t create_root_diag( ctrl_controller_t *controller )
+static data_row_t create_root_diag( ctrl_controller_t *controller )
 {
     u8_error_t ctrl_err;
     u8_error_t data_err;
@@ -102,11 +102,11 @@ static data_row_id_t create_root_diag( ctrl_controller_t *controller )
     diagram_ctrl = ctrl_controller_get_diagram_control_ptr( controller );
 
     /* create a diagram */
-    data_row_id_t root_diag_id;
+    data_row_t root_diag_id;
 
     data_diagram_t root_diagram;
     data_err = data_diagram_init_new( &root_diagram,
-                                      DATA_ROW_ID_VOID /*=parent_diagram_id*/,
+                                      DATA_ROW_VOID /*=parent_diagram_id*/,
                                       DATA_DIAGRAM_TYPE_UML_CLASS_DIAGRAM,
                                       "stereo_t",  /* stereotype */
                                       "Th& <root> d\"agram",
@@ -116,14 +116,14 @@ static data_row_id_t create_root_diag( ctrl_controller_t *controller )
                                     );
     TEST_ENVIRONMENT_ASSERT( U8_ERROR_NONE == data_err );
 
-    root_diag_id = DATA_ROW_ID_VOID;
+    root_diag_id = DATA_ROW_VOID;
     ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
                                                         &root_diagram,
                                                         CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                         &root_diag_id
                                                       );
     TEST_ENVIRONMENT_ASSERT( U8_ERROR_NONE == ctrl_err );
-    TEST_ENVIRONMENT_ASSERT( DATA_ROW_ID_VOID != root_diag_id );
+    TEST_ENVIRONMENT_ASSERT( DATA_ROW_VOID != root_diag_id );
     data_diagram_destroy ( &root_diagram );
 
     return root_diag_id;
@@ -166,7 +166,7 @@ static test_case_result_t test_md_plain_mixed( test_fixture_t *fix )
 static test_case_result_t test_valid_links( test_fixture_t *fix )
 {
     assert( fix != NULL );
-    data_row_id_t root_diag_id = create_root_diag( &((*fix).controller) );
+    data_row_t root_diag_id = create_root_diag( &((*fix).controller) );
     TEST_ENVIRONMENT_ASSERT( 1 == root_diag_id );  /* otherwise D0001 needs to be adapted (hint: delete old database file) */
     int err;
 
@@ -187,7 +187,7 @@ static test_case_result_t test_valid_links( test_fixture_t *fix )
 static test_case_result_t test_invalid_links( test_fixture_t *fix )
 {
     assert( fix != NULL );
-    data_row_id_t root_diag_id = create_root_diag( &((*fix).controller) );
+    data_row_t root_diag_id = create_root_diag( &((*fix).controller) );
     TEST_ENVIRONMENT_ASSERT( 1 == root_diag_id );  /* otherwise D0001 needs to be adapted (hint: delete old database file) */
     int err;
 
@@ -206,7 +206,7 @@ static test_case_result_t test_invalid_links( test_fixture_t *fix )
 
 
 /*
- * Copyright 2020-2024 Andreas Warnke
+ * Copyright 2020-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
