@@ -1,14 +1,29 @@
 /* File: test_main.c; Copyright and License: see below */
 
 /* data */
+#include "unit/entity_data_diagram_test.h"
+#include "unit/entity_data_diagramelement_test.h"
+#include "unit/entity_data_classifier_test.h"
+#include "unit/entity_data_feature_test.h"
+#include "unit/entity_data_relationship_test.h"
+#include "unit/entity_data_head_test.h"
+#include "unit/entity_data_id_test.h"
+#include "unit/entity_data_type_test.h"
+#include "unit/entity_data_uuid_test.h"
+#include "unit/set_data_full_id_list_test.h"
+#include "unit/set_data_full_id_test.h"
+#include "unit/set_data_search_result_list_test.h"
+#include "unit/set_data_search_result_test.h"
+#include "unit/set_data_small_set_test.h"
+#include "unit/set_data_stat_test.h"
+#include "unit/set_data_visible_classifier_test.h"
 #include "unit/data_change_notifier_test.h"
-#include "unit/data_small_set_test.h"
-#include "unit/data_uuid_test.h"
 #include "unit/data_rules_test.h"
 #include "unit/data_database_listener_test.h"
 #include "unit/data_database_head_test.h"
-#include "integration/data_profile_part_test.h"
 #include "integration/data_database_reader_test.h"
+#include "integration/data_profile_part_test.h"
+#include "integration/data_visible_set_test.h"
 /* ctrl */
 #include "integration/ctrl_diagram_controller_test.h"
 #include "integration/ctrl_multi_step_changer_test.h"
@@ -17,13 +32,14 @@
 #include "integration/ctrl_undo_redo_list_test.h"
 #include "integration/consistency_lifeline_test.h"
 #include "integration/consistency_drop_invisibles_test.h"
+#include "unit/ctrl_undo_redo_iterator_test.h"
 /* pencil */
 #include "unit/geometry_rectangle_test.h"
 #include "unit/geometry_connector_test.h"
 #include "unit/geometry_non_linear_scale_test.h"
 #include "unit/layout_visible_set_test.h"
 #include "unit/draw_classifier_contour_test.h"
-#include "unit/draw_stereotype_image_test.h"
+#include "unit/draw_stereotype_icon_test.h"
 #include "unit/pencil_classifier_composer_test.h"
 #include "integration/pencil_layouter_test.h"
 #include "integration/pencil_diagram_maker_test.h"
@@ -192,17 +208,34 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, utf8stream_writer_test_get_suite() );
 
         /* data */
-        test_runner_run_suite( &runner, data_small_set_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_diagram_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_diagramelement_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_classifier_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_feature_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_relationship_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_head_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_id_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_type_test_get_suite() );
+        test_runner_run_suite( &runner, entity_data_uuid_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_full_id_list_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_full_id_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_search_result_list_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_search_result_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_small_set_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_stat_test_get_suite() );
+        test_runner_run_suite( &runner, set_data_visible_classifier_test_get_suite() );
         test_runner_run_suite( &runner, data_rules_test_get_suite() );
-        test_runner_run_suite( &runner, data_uuid_test_get_suite() );
         test_runner_run_suite( &runner, data_change_notifier_test_get_suite() );
         test_runner_run_suite( &runner, data_database_listener_test_get_suite() );
         test_runner_run_suite( &runner, data_database_head_test_get_suite() );
 
         test_runner_run_suite( &runner, data_database_reader_test_get_suite() );
         test_runner_run_suite( &runner, data_profile_part_test_get_suite() );
+        test_runner_run_suite( &runner, data_visible_set_test_get_suite() );
 
         /* ctrl */
+        test_runner_run_suite( &runner, ctrl_undo_redo_iterator_test_get_suite() );
+
         test_runner_run_suite( &runner, ctrl_multi_step_changer_test_get_suite() );
         test_runner_run_suite( &runner, ctrl_diagram_controller_test_get_suite() );
         test_runner_run_suite( &runner, ctrl_classifier_controller_test_get_suite() );
@@ -217,7 +250,7 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
         test_runner_run_suite( &runner, layout_visible_set_test_get_suite() );
         test_runner_run_suite( &runner, draw_classifier_contour_test_get_suite() );
-        test_runner_run_suite( &runner, draw_stereotype_image_test_get_suite() );
+        test_runner_run_suite( &runner, draw_stereotype_icon_test_get_suite() );
         test_runner_run_suite( &runner, pencil_classifier_composer_test_get_suite() );
 
         test_runner_run_suite( &runner, pencil_layouter_test_get_suite() );
@@ -257,7 +290,7 @@ int main (int argc, char *argv[]) {
 
 
 /*
- * Copyright 2016-2024 Andreas Warnke
+ * Copyright 2016-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
