@@ -15,12 +15,13 @@
 #include "pencil_feature_layouter.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_dimensions.h"
-#include "geometry/geometry_non_linear_scale.h"
+#include "geometry/geometry_grid.h"
+#include "geometry/geometry_offset.h"
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_visible_set.h"
-#include "data_diagram.h"
-#include "data_id.h"
+#include "entity/data_diagram.h"
+#include "entity/data_id.h"
 #include "u8list/universal_array_index_sorter.h"
 #include <cairo.h>
 #include <stdint.h>
@@ -39,8 +40,7 @@ struct pencil_classifier_2d_layouter_struct {
                                        /*!< defining pen sizes, gap sizes, font sizes and colors */
     const geometry_rectangle_t *diagram_draw_area;  /*!< pointer to an external drawing rectangle */
                                                     /*!< containing inner contents of the diagram */
-    geometry_non_linear_scale_t *x_scale;  /*!< pointer to an external scale object for the x-axis */
-    geometry_non_linear_scale_t *y_scale;  /*!< pointer to an external scale object for the y-axis */
+    const geometry_grid_t *grid;  /*!< pointer to an external pair of scale objects to calculate positions from order numbers */
     geometry_dimensions_t *default_classifier_size;  /*!< pointer to an external classifier default size rectangle */
 
     pencil_classifier_composer_t classifier_composer;  /*!< own instance of a composer object to ask for display dimensions */
@@ -58,8 +58,7 @@ typedef struct pencil_classifier_2d_layouter_struct pencil_classifier_2d_layoute
  *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be layouted
  *  \param pencil_size pointer to the pencil_size_t object
  *  \param default_classifier_size pointer to the default size of a classifier
- *  \param x_scale pointer to the scale object for the x-axis
- *  \param y_scale pointer to the scale object for the y-axis
+ *  \param grid pointer to an external pair of scale objects to calculate positions from order numbers
  *  \param feature_layouter pointer to a feature layout helper
  */
 void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
@@ -67,8 +66,7 @@ void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
                                          const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size,
                                          geometry_dimensions_t *default_classifier_size,
-                                         geometry_non_linear_scale_t *x_scale,
-                                         geometry_non_linear_scale_t *y_scale,
+                                         const geometry_grid_t *grid,
                                          pencil_feature_layouter_t *feature_layouter
                                        );
 
@@ -104,7 +102,9 @@ void pencil_classifier_2d_layouter_move_to_avoid_overlaps ( pencil_classifier_2d
  *  \param this_ pointer to own object attributes
  *  \param out_sorted sorting order by which to move classifiers; must not be NULL, shall be initialized to empty.
  */
-void pencil_classifier_2d_layouter_private_propose_move_processing_order ( pencil_classifier_2d_layouter_t *this_, universal_array_index_sorter_t *out_sorted );
+void pencil_classifier_2d_layouter_private_propose_move_processing_order ( pencil_classifier_2d_layouter_t *this_,
+                                                                           universal_array_index_sorter_t *out_sorted
+                                                                         );
 
 /*!
  *  \brief propose multiple solutions to move one classifier up/down/left/right
@@ -113,17 +113,15 @@ void pencil_classifier_2d_layouter_private_propose_move_processing_order ( penci
  *  \param sorted sorting order by which to move classifiers; must not be NULL.
  *  \param sort_index index of the current classifier for which to propose solutions
  *  \param solutions_max maximum number (array size) of solutions to propose
- *  \param out_solution_move_dx array of solutions: proposal to move in x direction
- *  \param out_solution_move_dy array of solutions: proposal to move in y direction
- *  \param out_solutions_count number of proposed solutions; 1 &lt;= out_solutions_count &lt; solutions_max
+ *  \param out_solution array of solutions: proposal to move in x/y direction
+ *  \param out_solution_count number of proposed solutions; 1 &lt;= out_solution_count &lt; solutions_max
  */
 void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions ( pencil_classifier_2d_layouter_t *this_,
                                                                          const universal_array_index_sorter_t *sorted,
                                                                          uint32_t sort_index,
                                                                          uint32_t solutions_max,
-                                                                         double out_solution_move_dx[],
-                                                                         double out_solution_move_dy[],
-                                                                         uint32_t *out_solutions_count
+                                                                         geometry_offset_t (*out_solution)[],
+                                                                         uint32_t *out_solution_count
                                                                        );
 
 /*!
@@ -132,14 +130,12 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions ( pencil_
  *  \param this_ pointer to own object attributes
  *  \param sorted sorting order by which to move classifiers; must not be NULL.
  *  \param sort_index index of the current classifier for which to propose solutions
- *  \param out_solution_move_dx proposal to move in x direction
- *  \param out_solution_move_dy proposal to move in y direction
+ *  \param out_solution proposal to move in x/y direction
  */
 void pencil_classifier_2d_layouter_private_propose_anchored_solution ( pencil_classifier_2d_layouter_t *this_,
                                                                        const universal_array_index_sorter_t *sorted,
                                                                        uint32_t sort_index,
-                                                                       double * out_solution_move_dx,
-                                                                       double * out_solution_move_dy
+                                                                       geometry_offset_t *out_solution
                                                                      );
 
 /*!
@@ -148,17 +144,15 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution ( pencil_cl
  *  \param this_ pointer to own object attributes
  *  \param sorted sorting order by which to move classifiers; must not be NULL.
  *  \param sort_index index (in sorted classifiers) of the current classifier for which to select a solution
- *  \param solutions_count number of proposed solutions; 1 &lt;= out_solutions_count &lt; solutions_max
- *  \param solution_move_dx array of solutions: proposal to move in x direction
- *  \param solution_move_dy array of solutions: proposal to move in y direction
+ *  \param out_solution_count number of proposed solutions; 1 &lt;= out_solution_count
+ *  \param solution array of solutions: proposal to move in x/y direction
  *  \param out_index_of_best index (of solution) of the best solution; must not be NULL.
  */
 void pencil_classifier_2d_layouter_private_select_move_solution ( pencil_classifier_2d_layouter_t *this_,
                                                                   const universal_array_index_sorter_t *sorted,
                                                                   uint32_t sort_index,
-                                                                  uint32_t solutions_count,
-                                                                  const double solution_move_dx[],
-                                                                  const double solution_move_dy[],
+                                                                  uint32_t out_solution_count,
+                                                                  geometry_offset_t (*solution)[],
                                                                   uint32_t *out_index_of_best
                                                                 );
 
@@ -253,13 +247,11 @@ static inline geometry_rectangle_t pencil_classifier_2d_layouter_private_calc_ou
  *
  *  \param this_ pointer to own object attributes
  *  \param ancestor_classifier the ancestor classifier
- *  \param delta_x distance to move in x direction
- *  \param delta_y distance to move in y direction
+ *  \param offset distance to move all children/descendants
  */
 static inline void pencil_classifier_2d_layouter_private_move_descendants( pencil_classifier_2d_layouter_t *this_,
                                                                            const layout_visible_classifier_t *ancestor_classifier,
-                                                                           double delta_x,
-                                                                           double delta_y
+                                                                           const geometry_offset_t *offset
                                                                          );
 
 
@@ -269,7 +261,7 @@ static inline void pencil_classifier_2d_layouter_private_move_descendants( penci
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
