@@ -17,8 +17,8 @@
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_visible_set.h"
-#include "data_diagram.h"
-#include "data_id.h"
+#include "entity/data_diagram.h"
+#include "entity/data_id.h"
 #include "u8list/universal_array_index_sorter.h"
 #include "u8/u8_error.h"
 #include <cairo.h>
@@ -291,7 +291,7 @@ void pencil_relationship_2d_layouter_layout_for_communication( pencil_relationsh
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
