@@ -419,9 +419,144 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
     return result;
 }
 
+int geometry_rectangle_init_by_difference_at_pivot( geometry_rectangle_t *this_,
+                                                    const geometry_rectangle_t *moon,
+                                                    const geometry_rectangle_t *shadow,
+                                                    const geometry_point_t *pivot_point )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != moon );
+    assert( NULL != shadow );
+    assert( NULL != pivot_point );
+
+    int result = 0;
+
+    const double moon_left = geometry_rectangle_get_left( moon );
+    const double moon_right = geometry_rectangle_get_right( moon );
+    const double moon_top = geometry_rectangle_get_top( moon );
+    const double moon_bottom = geometry_rectangle_get_bottom( moon );
+    const double moon_width = geometry_rectangle_get_width( moon );
+    const double moon_height = geometry_rectangle_get_height( moon );
+
+    geometry_rectangle_t shadow_intersect;
+    const int no_overlap = geometry_rectangle_init_by_intersect( &shadow_intersect, moon, shadow );
+    if ( no_overlap == 0 )
+    {
+        const double shadow_left = geometry_rectangle_get_left( &shadow_intersect );
+        const double shadow_top = geometry_rectangle_get_top( &shadow_intersect );
+        const double shadow_right = geometry_rectangle_get_right( &shadow_intersect );
+        const double shadow_bottom = geometry_rectangle_get_bottom( &shadow_intersect );
+        const double left_width = shadow_left - moon_left;
+        const double top_height = shadow_top - moon_top;
+        const double right_width = moon_right - shadow_right;
+        const double bottom_height = moon_bottom - shadow_bottom;
+
+        geometry_direction_t keep;
+        if ( geometry_point_get_x( pivot_point ) <= shadow_left )
+        {
+            if ( geometry_point_get_y( pivot_point ) <= shadow_top )
+            {
+                keep = ( left_width > top_height ) ? GEOMETRY_DIRECTION_LEFT : GEOMETRY_DIRECTION_UP;
+            }
+            else if ( geometry_point_get_y( pivot_point ) >= shadow_bottom )
+            {
+                keep = ( left_width > bottom_height ) ? GEOMETRY_DIRECTION_LEFT : GEOMETRY_DIRECTION_DOWN;
+            }
+            else
+            {
+                keep = GEOMETRY_DIRECTION_LEFT;
+            }
+        }
+        else if ( geometry_point_get_x( pivot_point ) >= shadow_right )
+        {
+            if ( geometry_point_get_y( pivot_point ) <= shadow_top )
+            {
+                keep = ( right_width > top_height ) ? GEOMETRY_DIRECTION_RIGHT : GEOMETRY_DIRECTION_UP;
+            }
+            else if ( geometry_point_get_y( pivot_point ) >= shadow_bottom )
+            {
+                keep = ( right_width > bottom_height ) ? GEOMETRY_DIRECTION_RIGHT : GEOMETRY_DIRECTION_DOWN;
+            }
+            else
+            {
+                keep = GEOMETRY_DIRECTION_RIGHT;
+            }
+        }
+        else
+        {
+            if ( geometry_point_get_y( pivot_point ) <= shadow_top )
+            {
+                keep = GEOMETRY_DIRECTION_UP;
+            }
+            else if ( geometry_point_get_y( pivot_point ) >= shadow_bottom )
+            {
+                keep = GEOMETRY_DIRECTION_DOWN;
+            }
+            else
+            {
+                if ( geometry_point_get_x( pivot_point ) < geometry_rectangle_get_center_x( &shadow_intersect ) )
+                {
+                    if ( geometry_point_get_y( pivot_point ) < geometry_rectangle_get_center_y( &shadow_intersect ) )
+                    {
+                        keep = ( left_width > top_height ) ? GEOMETRY_DIRECTION_LEFT : GEOMETRY_DIRECTION_UP;
+                    }
+                    else
+                    {
+                        keep = ( left_width > bottom_height ) ? GEOMETRY_DIRECTION_LEFT : GEOMETRY_DIRECTION_DOWN;
+                    }
+                }
+                else
+                {
+                    if ( geometry_point_get_y( pivot_point ) < geometry_rectangle_get_center_y( &shadow_intersect ) )
+                    {
+                        keep = ( right_width > top_height ) ? GEOMETRY_DIRECTION_RIGHT : GEOMETRY_DIRECTION_UP;
+                    }
+                    else
+                    {
+                        keep = ( right_width > bottom_height ) ? GEOMETRY_DIRECTION_RIGHT : GEOMETRY_DIRECTION_DOWN;
+                    }
+                }
+            }
+        }
+
+        if ( keep == GEOMETRY_DIRECTION_LEFT )
+        {
+            /* take left side of shadow_intersect */
+            geometry_rectangle_init( this_, moon_left, moon_top, shadow_left - moon_left, moon_height );
+            U8_TRACE_INFO_INT_INT( "left: w*h", left_width, moon_height );
+        }
+        else if ( keep == GEOMETRY_DIRECTION_RIGHT )
+        {
+            /* take right side of shadow_intersect */
+            geometry_rectangle_init( this_, shadow_right, moon_top, moon_right - shadow_right, moon_height );
+            U8_TRACE_INFO_INT_INT( "right: w*h", right_width, moon_height);
+        }
+        else if ( keep == GEOMETRY_DIRECTION_DOWN )
+        {
+            /* take bottom side of shadow_intersect */
+            geometry_rectangle_init( this_, moon_left, shadow_bottom, moon_width, moon_bottom - shadow_bottom );
+            U8_TRACE_INFO_INT_INT( "bottom: w*h", moon_width, bottom_height);
+        }
+        else
+        {
+            /* take top side of shadow_intersect */
+            geometry_rectangle_init( this_, moon_left, moon_top, moon_width, shadow_top - moon_top );
+            U8_TRACE_INFO_INT_INT( "top: w*h", moon_width, top_height);
+        }
+    }
+    else
+    {
+        *this_ = *moon;
+        U8_TRACE_INFO_INT_INT( "no intersect: w*h", moon_width, moon_height );
+    }
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
