@@ -1,6 +1,9 @@
 /* File: pencil_classifier_2d_layouter.c; Copyright and License: see below */
 
 #include "pencil_classifier_2d_layouter.h"
+#include "layout/layout_quality.h"
+#include "layout/layout_visible_classifier_iter.h"
+#include "geometry/geometry_non_linear_scale.h"
 #include "u8/u8_trace.h"
 #include <pango/pangocairo.h>
 #include <stdio.h>
@@ -12,8 +15,7 @@ void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
                                          const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size,
                                          geometry_dimensions_t *default_classifier_size,
-                                         geometry_non_linear_scale_t *x_scale,
-                                         geometry_non_linear_scale_t *y_scale,
+                                         const geometry_grid_t *grid,
                                          pencil_feature_layouter_t *feature_layouter )
 {
     U8_TRACE_BEGIN();
@@ -21,23 +23,21 @@ void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
     assert( NULL != profile );
     assert( NULL != pencil_size );
     assert( NULL != default_classifier_size );
-    assert( NULL != x_scale );
-    assert( NULL != y_scale );
+    assert( NULL != grid );
     assert( NULL != feature_layouter );
 
     (*this_).layout_data = layout_data;
     (*this_).profile = profile;
     (*this_).pencil_size = pencil_size;
     (*this_).default_classifier_size = default_classifier_size;
-    (*this_).x_scale = x_scale;
-    (*this_).y_scale = y_scale;
+    (*this_).grid = grid;
     (*this_).feature_layouter = feature_layouter;
     pencil_classifier_composer_init( &((*this_).classifier_composer) );
 
     /* get draw area */
     {
-        layout_diagram_t *diagram_layout;
-        diagram_layout = layout_visible_set_get_diagram_ptr( (*this_).layout_data );
+        const layout_diagram_t *const diagram_layout
+            = layout_visible_set_get_diagram_ptr( (*this_).layout_data );
         (*this_).diagram_draw_area = layout_diagram_get_draw_area_const( diagram_layout );
     }
 
@@ -64,7 +64,16 @@ void pencil_classifier_2d_layouter_estimate_bounds( pencil_classifier_2d_layoute
     for ( uint32_t index = 0; index < count_clasfy; index ++ )
     {
         layout_visible_classifier_t *const classifier_layout
-             = layout_visible_set_get_visible_classifier_ptr ( (*this_).layout_data, index );
+            = layout_visible_set_get_visible_classifier_ptr ( (*this_).layout_data, index );
+
+        /* trace */
+        {
+            const data_visible_classifier_t *const visible_classifier
+                = layout_visible_classifier_get_data_const( classifier_layout );
+            const data_classifier_t *const classifier
+                = data_visible_classifier_get_classifier_const( visible_classifier );
+            U8_TRACE_INFO_STR( "classifier:", data_classifier_get_name_const( classifier ) );
+        }
 
         /* set the bounds, space and label_box of the classifier layout */
         {
@@ -137,7 +146,7 @@ void pencil_classifier_2d_layouter_estimate_bounds( pencil_classifier_2d_layoute
         /* move the classifier rectangles to the target location */
         {
             const data_visible_classifier_t *const visible_classifier2
-                = layout_visible_classifier_get_data_const ( classifier_layout );
+                = layout_visible_classifier_get_data_const( classifier_layout );
             const data_classifier_t *const classifier2
                 = data_visible_classifier_get_classifier_const( visible_classifier2 );
             const geometry_rectangle_t *const classifier_symbol_box
@@ -147,9 +156,12 @@ void pencil_classifier_2d_layouter_estimate_bounds( pencil_classifier_2d_layoute
             const double act_center_y = geometry_rectangle_get_center_y( classifier_symbol_box );
             const int32_t order_x = data_classifier_get_x_order( classifier2 );
             const int32_t order_y = data_classifier_get_y_order( classifier2 );
-            const double center_x = geometry_non_linear_scale_get_location( (*this_).x_scale, order_x );
-            const double center_y = geometry_non_linear_scale_get_location( (*this_).y_scale, order_y );
-            layout_visible_classifier_shift( classifier_layout, center_x-act_center_x, center_y-act_center_y );
+            const geometry_non_linear_scale_t *const x_scale = geometry_grid_get_x_scale_const( (*this_).grid );
+            const geometry_non_linear_scale_t *const y_scale = geometry_grid_get_y_scale_const( (*this_).grid );
+            const double center_x = geometry_non_linear_scale_get_location( x_scale, order_x );
+            const double center_y = geometry_non_linear_scale_get_location( y_scale, order_y );
+            const geometry_offset_t offset = geometry_offset_new( center_x - act_center_x, center_y - act_center_y );
+            layout_visible_classifier_shift( classifier_layout, &offset );
         }
     }
 
@@ -170,37 +182,49 @@ void pencil_classifier_2d_layouter_move_to_avoid_overlaps ( pencil_classifier_2d
     pencil_classifier_2d_layouter_private_propose_move_processing_order ( this_, &sorted );
 
     /* move the classifiers */
-    uint32_t count_sorted;
-    count_sorted = universal_array_index_sorter_get_count( &sorted );
+    const uint32_t count_sorted = universal_array_index_sorter_get_count( &sorted );
     for ( uint32_t sort_index = 0; sort_index < count_sorted; sort_index ++ )
     {
+        /* get iteration-specific data */
+        const uint32_t index
+            = universal_array_index_sorter_get_array_index( &sorted, sort_index );
+        layout_visible_classifier_t *const layouted_classifier
+            = layout_visible_set_get_visible_classifier_ptr( (*this_).layout_data, index );
+
+        /* trace */
+        {
+            const data_visible_classifier_t *const visible_classifier
+                = layout_visible_classifier_get_data_const( layouted_classifier );
+            const data_classifier_t *const classifier
+                = data_visible_classifier_get_classifier_const( visible_classifier );
+            U8_TRACE_INFO_STR( "classifier:", data_classifier_get_name_const( classifier ) );
+        }
+
         /* declaration of list of options */
-        uint32_t solutions_count = 0;
-        static const uint32_t SOLUTIONS_MAX = 6;
-        double solution_move_dx[6];
-        double solution_move_dy[6];
+        uint32_t solution_count = 0;
+        static const uint32_t SOLUTION_MAX = 6;
+        geometry_offset_t solution[6];
 
         /* propose options of moving left/right/up/down */
         pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( this_,
                                                                            &sorted,
                                                                            sort_index,
-                                                                           SOLUTIONS_MAX-1,
-                                                                           solution_move_dx,
-                                                                           solution_move_dy,
-                                                                           &solutions_count
+                                                                           SOLUTION_MAX-1,
+                                                                           &solution,
+                                                                           &solution_count
                                                                          );
+        assert( solution_count < SOLUTION_MAX );
         /* propose options of moving close at origin-area */
         pencil_classifier_2d_layouter_private_propose_anchored_solution( this_,
                                                                          &sorted,
                                                                          sort_index,
-                                                                         &(solution_move_dx[solutions_count]),
-                                                                         &(solution_move_dy[solutions_count])
+                                                                         &(solution[solution_count])
                                                                        );
-        solutions_count ++;
+        solution_count ++;
 
         /* select best option */
         uint32_t index_of_best;
-        if ( 1 == solutions_count )
+        if ( 1 == solution_count )
         {
             index_of_best = 0;
         }
@@ -209,20 +233,18 @@ void pencil_classifier_2d_layouter_move_to_avoid_overlaps ( pencil_classifier_2d
             pencil_classifier_2d_layouter_private_select_move_solution( this_,
                                                                         &sorted,
                                                                         sort_index,
-                                                                        solutions_count,
-                                                                        solution_move_dx,
-                                                                        solution_move_dy,
+                                                                        solution_count,
+                                                                        &solution,
                                                                         &index_of_best
                                                                       );
         }
 
-        /* perform best option */
-        uint32_t index;
-        index = universal_array_index_sorter_get_array_index( &sorted, sort_index );
         /* move the classifier */
-        layout_visible_classifier_t *the_classifier;
-        the_classifier = layout_visible_set_get_visible_classifier_ptr( (*this_).layout_data, index );
-        layout_visible_classifier_shift( the_classifier, solution_move_dx[index_of_best], solution_move_dy[index_of_best] );
+        layout_visible_classifier_shift( layouted_classifier, &(solution[index_of_best]) );
+        U8_TRACE_INFO_INT_INT( "classifier moved:",
+                               geometry_offset_get_dx( &(solution[index_of_best]) ),
+                               geometry_offset_get_dy( &(solution[index_of_best]) )
+                             );
     }
 
     universal_array_index_sorter_destroy( &sorted );
@@ -305,9 +327,8 @@ void pencil_classifier_2d_layouter_private_propose_move_processing_order ( penci
             }
         }
 
-        int insert_error;
-        insert_error = universal_array_index_sorter_insert( out_sorted, index, simpleness );
-        if ( 0 != insert_error )
+        const u8_error_t insert_error = universal_array_index_sorter_insert( out_sorted, index, simpleness );
+        if ( U8_ERROR_NONE != insert_error )
         {
             U8_LOG_WARNING( "not all rectangles are moved" );
         }
@@ -332,16 +353,14 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( pencil_c
                                                                         const universal_array_index_sorter_t *sorted,
                                                                         uint32_t sort_index,
                                                                         uint32_t solutions_max,
-                                                                        double out_solution_move_dx[],
-                                                                        double out_solution_move_dy[],
-                                                                        uint32_t *out_solutions_count )
+                                                                        geometry_offset_t (*out_solution)[],
+                                                                        uint32_t *out_solution_count )
 {
     U8_TRACE_BEGIN();
     assert ( NULL != sorted );
     assert ( universal_array_index_sorter_get_count( sorted ) > sort_index );
-    assert ( NULL != out_solution_move_dx );
-    assert ( NULL != out_solution_move_dy );
-    assert ( NULL != out_solutions_count );
+    assert ( NULL != out_solution );
+    assert ( NULL != out_solution_count );
     assert ( 1 <= solutions_max );  /* general requirement to report at least one option */
     assert ( (unsigned int) PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_MAX <= solutions_max );  /* current implementation requires at least 5 options */
 
@@ -361,7 +380,7 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( pencil_c
     double shift_x = 0.0;
     double shift_y = 0.0;
 
-    /* check overlap to diagram boundary */
+    /* initial check of overlaps to diagram boundary */
     {
         if ( bottom > geometry_rectangle_get_bottom( (*this_).diagram_draw_area ) )
         {
@@ -381,21 +400,16 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( pencil_c
         }
     }
 
-    *out_solutions_count = 1;
-    out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_NOT] = shift_x;
-    out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_NOT] = shift_y;
+    *out_solution_count = 1;
+    (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_NOT] = geometry_offset_new( shift_x, shift_y );
 
     /* determine minimum and comfort distances between classifiers */
     const double gap = pencil_size_get_standard_object_border( (*this_).pencil_size );
 
-    out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] = shift_x;
-    out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] = shift_y;
-    out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] = shift_x;
-    out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] = shift_y;
-    out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] = shift_x;
-    out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] = shift_y;
-    out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] = shift_x;
-    out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] = shift_y;
+    (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] = geometry_offset_new( shift_x, shift_y );
+    (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] = geometry_offset_new( shift_x, shift_y );
+    (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] = geometry_offset_new( shift_x, shift_y );
+    (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] = geometry_offset_new( shift_x, shift_y );
 
     /* adjust information on current rectangle */
     top += shift_y;
@@ -448,37 +462,37 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( pencil_c
 
             double my_shift_x_left_min;
             my_shift_x_left_min = probe_left - right - gap;
-            if ( my_shift_x_left_min < out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] )
+            if ( my_shift_x_left_min < geometry_offset_get_dx( &((*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN]) ) )
             {
-                out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] = my_shift_x_left_min;
+                (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_LEFT_MIN] = geometry_offset_new( my_shift_x_left_min, shift_y );
             }
 
             double my_shift_x_right_min;
             my_shift_x_right_min = probe_right - left + gap;
-            if ( my_shift_x_right_min > out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] )
+            if ( my_shift_x_right_min > geometry_offset_get_dx( &((*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN]) ) )
             {
-                out_solution_move_dx[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] = my_shift_x_right_min;
+                (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_RIGHT_MIN] = geometry_offset_new( my_shift_x_right_min, shift_y );
             }
 
             double my_shift_y_up_min;
             my_shift_y_up_min = probe_top - bottom - gap;
-            if ( my_shift_y_up_min < out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] )
+            if ( my_shift_y_up_min < geometry_offset_get_dy( &((*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN]) ) )
             {
-                out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] = my_shift_y_up_min;
+                (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_UP_MIN] = geometry_offset_new( shift_x, my_shift_y_up_min );
             }
 
             double my_shift_y_down_min;
             my_shift_y_down_min = probe_bottom - top + gap;
-            if ( my_shift_y_down_min > out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] )
+            if ( my_shift_y_down_min > geometry_offset_get_dy( &((*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN]) ) )
             {
-                out_solution_move_dy[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] = my_shift_y_down_min;
+                (*out_solution)[PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_DOWN_MIN] = geometry_offset_new( shift_x, my_shift_y_down_min );
             }
 
-            *out_solutions_count = PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_MAX;
+            *out_solution_count = PENCIL_CLASSIFIER_LAYOUTER_PRIVATE_MOVE_MAX;
 
             /* trace */
             const data_visible_classifier_t *visible_classifier_data;
-            visible_classifier_data = layout_visible_classifier_get_data_const ( the_probe );
+            visible_classifier_data = layout_visible_classifier_get_data_const( the_probe );
             if (( visible_classifier_data != NULL ) && ( data_visible_classifier_is_valid( visible_classifier_data ) ))
             {
                 const data_classifier_t *classifier_p;
@@ -488,27 +502,18 @@ void pencil_classifier_2d_layouter_private_propose_4dir_move_solutions( pencil_c
         }
     }
 
-    /* trace */
-    const data_visible_classifier_t *visible_classifier;
-    visible_classifier = layout_visible_classifier_get_data_const ( the_classifier );
-    const data_classifier_t *classifier;
-    classifier = data_visible_classifier_get_classifier_const( visible_classifier );
-    U8_TRACE_INFO_STR( "classifier:", data_classifier_get_name_const( classifier ) );
-
     U8_TRACE_END();
 }
 
 void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_classifier_2d_layouter_t *this_,
                                                                       const universal_array_index_sorter_t *sorted,
                                                                       uint32_t sort_index,
-                                                                      double * out_solution_move_dx,
-                                                                      double * out_solution_move_dy )
+                                                                      geometry_offset_t *out_solution )
 {
     U8_TRACE_BEGIN();
     assert ( NULL != sorted );
     assert ( universal_array_index_sorter_get_count( sorted ) > sort_index );
-    assert ( NULL != out_solution_move_dx );
-    assert ( NULL != out_solution_move_dy );
+    assert ( NULL != out_solution );
 
     /* get classifier to move */
     const uint32_t index
@@ -525,12 +530,12 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_cla
 
     /* wish a solution area */
     geometry_rectangle_t classifier_solution_area;
-    geometry_rectangle_init ( &classifier_solution_area,
-                              geometry_rectangle_get_left( classifier_envelope_box ) - 0.5*width - gap,
-                              geometry_rectangle_get_top( classifier_envelope_box ) - 0.5*height - gap,
-                              2.0*width + 2.0*gap,
-                              2.0*height + 2.0*gap
-                            );
+    geometry_rectangle_init( &classifier_solution_area,
+                             geometry_rectangle_get_left( classifier_envelope_box ) - 0.5*width - gap,
+                             geometry_rectangle_get_top( classifier_envelope_box ) - 0.5*height - gap,
+                             2.0*width + 2.0*gap,
+                             2.0*height + 2.0*gap
+                           );
 
     /* shrink solution area to diagram_draw_area */
     geometry_rectangle_init_by_intersect( &classifier_solution_area,
@@ -564,6 +569,8 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_cla
     geometry_rectangle_enlarge ( &classifier_solution_area, -2.0*gap, -2.0*gap );
 
     /* move - but not to eager - only the minumum distance */
+    double solution_move_dx = 0.0;
+    double solution_move_dy = 0.0;
     const bool is_x_contained
         = ( geometry_rectangle_get_left( &classifier_solution_area ) < geometry_rectangle_get_left( classifier_envelope_box ) )
         && ( geometry_rectangle_get_right( classifier_envelope_box ) < geometry_rectangle_get_right( &classifier_solution_area ) );
@@ -572,13 +579,13 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_cla
         && ( geometry_rectangle_get_bottom( classifier_envelope_box ) < geometry_rectangle_get_bottom( &classifier_solution_area ) );
     if ( is_x_contained )
     {
-        *out_solution_move_dx = 0.0;
+        solution_move_dx = 0.0;
     }
     else
     {
         const double sol_center_x = geometry_rectangle_get_center_x( &classifier_solution_area );
         const double cur_center_x = geometry_rectangle_get_center_x( classifier_envelope_box );
-        *out_solution_move_dx = ( sol_center_x < cur_center_x )
+        solution_move_dx = ( sol_center_x < cur_center_x )
             ? geometry_rectangle_get_right( &classifier_solution_area )
             - geometry_rectangle_get_right( classifier_envelope_box )
             : geometry_rectangle_get_left( &classifier_solution_area )
@@ -588,22 +595,23 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_cla
     }
     if ( is_y_contained )
     {
-        *out_solution_move_dy = 0.0;
+        solution_move_dy = 0.0;
     }
     else
     {
         const double sol_center_y = geometry_rectangle_get_center_y( &classifier_solution_area );
         const double cur_center_y = geometry_rectangle_get_center_y( classifier_envelope_box );
-        *out_solution_move_dy = ( sol_center_y < cur_center_y )
+        solution_move_dy = ( sol_center_y < cur_center_y )
             ? geometry_rectangle_get_bottom( &classifier_solution_area )
             - geometry_rectangle_get_bottom( classifier_envelope_box )
             : geometry_rectangle_get_top( &classifier_solution_area )
             - geometry_rectangle_get_top( classifier_envelope_box );
     }
+    *out_solution = geometry_offset_new( solution_move_dx, solution_move_dy );
 
     /* trace */
     const data_visible_classifier_t *visible_classifier;
-    visible_classifier = layout_visible_classifier_get_data_const ( the_classifier );
+    visible_classifier = layout_visible_classifier_get_data_const( the_classifier );
     const data_classifier_t *classifier;
     classifier = data_visible_classifier_get_classifier_const( visible_classifier );
     U8_TRACE_INFO_STR( "classifier:", data_classifier_get_name_const( classifier ) );
@@ -614,60 +622,43 @@ void pencil_classifier_2d_layouter_private_propose_anchored_solution( pencil_cla
 void pencil_classifier_2d_layouter_private_select_move_solution( pencil_classifier_2d_layouter_t *this_,
                                                                  const universal_array_index_sorter_t *sorted,
                                                                  uint32_t sort_index,
-                                                                 uint32_t solutions_count,
-                                                                 const double solution_move_dx[],
-                                                                 const double solution_move_dy[],
+                                                                 uint32_t solution_count,
+                                                                 geometry_offset_t (*solution)[],
                                                                  uint32_t *out_index_of_best )
 {
     U8_TRACE_BEGIN();
     assert ( NULL != sorted );
     assert ( universal_array_index_sorter_get_count( sorted ) > sort_index );
-    assert ( NULL != solution_move_dx );
-    assert ( NULL != solution_move_dy );
+    assert ( NULL != solution );
     assert ( NULL != out_index_of_best );
-    assert ( 1 <= solutions_count );
+    assert ( 1 <= solution_count );
 
     /* define potential solution and rating */
-    uint32_t index_of_best;
-    double debts_of_best;
-    index_of_best = 0;  /* in case of doubts, take the first solution */
-    debts_of_best = 1000000000.0;
+    uint32_t index_of_best = 0;  /* in case of doubts, take the first solution */
+    double debts_of_best = DBL_MAX;
 
     /* get classifier to move */
     const uint32_t index
         = universal_array_index_sorter_get_array_index( sorted, sort_index );
     const layout_visible_classifier_t *const the_classifier
         = layout_visible_set_get_visible_classifier_ptr( (*this_).layout_data, index );
-    const geometry_rectangle_t *const classifier_envelope_box
-        = layout_visible_classifier_get_envelope_box_const( the_classifier );
 
     /* check all solutions */
-    for ( uint32_t solution_index = 0; solution_index < solutions_count; solution_index ++ )
+    for ( uint32_t solution_index = 0; solution_index < solution_count; solution_index ++ )
     {
-        /* calculate the solution rectangle */
-        geometry_rectangle_t solution_bounds;
-        geometry_rectangle_copy( &solution_bounds, classifier_envelope_box );
-        geometry_rectangle_shift ( &solution_bounds, solution_move_dx[solution_index], solution_move_dy[solution_index] );
+        /* calculate the solution classifier */
+        layout_visible_classifier_t moved_solution;
+        layout_visible_classifier_copy( &moved_solution, the_classifier );
+        layout_visible_classifier_shift( &moved_solution, &((*solution)[solution_index]) );
 
         /* evalute the debts of this solution */
-        double debts_of_current;
-        debts_of_current = 0.0;
+        double debts_of_current = 0.0;
 
-        /* add move distance as debt */
-        debts_of_current += fabs ( solution_move_dx[solution_index] );
-        debts_of_current += fabs ( solution_move_dy[solution_index] );
+        const layout_diagram_t *const diagram_layout
+            = layout_visible_set_get_diagram_ptr( (*this_).layout_data );
 
-        /* add debts for overlap to diagram boundary */
-        {
-            static const double DIAG_BOUNDS_SEVERITY = 32.0;
-
-            double current_area = geometry_rectangle_get_area ( &solution_bounds );
-            geometry_rectangle_t intersect;
-            geometry_rectangle_init_by_intersect( &intersect, &solution_bounds, (*this_).diagram_draw_area );
-            double intersect_area = geometry_rectangle_get_area ( &intersect );
-
-            debts_of_current += DIAG_BOUNDS_SEVERITY * ( current_area - intersect_area );
-        }
+        const layout_quality_t quality = layout_quality_new( (*this_).pencil_size );
+        debts_of_current += layout_quality_debts_class_diag( &quality, &moved_solution, &((*solution)[solution_index]), diagram_layout );
 
         /* check overlap to other classifiers */
         for ( uint32_t probe_sort_index = 0; probe_sort_index < universal_array_index_sorter_get_count( sorted ); probe_sort_index ++ )
@@ -680,37 +671,17 @@ void pencil_classifier_2d_layouter_private_select_move_solution( pencil_classifi
 
                 const layout_visible_classifier_t *const the_probe
                     = layout_visible_set_get_visible_classifier_const( (*this_).layout_data, probe_index );
-                const geometry_rectangle_t *const probe_envelope_box
-                    = layout_visible_classifier_get_envelope_box_const( the_probe );
 
-                geometry_rectangle_t probe_intersect;
-                const int intersect_err
-                    = geometry_rectangle_init_by_intersect( &probe_intersect, &solution_bounds, probe_envelope_box );
-                if ( 0 == intersect_err )
-                {
-                    /* there is an intersect */
-                    if ( layout_visible_set_is_ancestor( (*this_).layout_data, the_classifier, the_probe ) )
-                    {
-                        /* no debt: parent my overlap children */
-                    }
-                    else if ( layout_visible_set_is_ancestor( (*this_).layout_data, the_probe, the_classifier ) )
-                    {
-                        /* no debt: child may overlap parent */
-                    }
-                    else
-                    {
-                        /* already processed classifiers have higher severity because these do not move anymore */
-                        const double severity = ( probe_sort_index < sort_index ) ? 4.0 : 1.0;
-                        const double probe_intersect_area = geometry_rectangle_get_area ( &probe_intersect );
-                        debts_of_current += severity * probe_intersect_area;
-                    }
-                }
-                /* else no intersect/overlap */
+                /* already processed classifiers have higher severity because these do not move anymore */
+                const double severity = ( probe_sort_index < sort_index ) ? 1.0 : 0.25;
+
+                debts_of_current += severity * layout_quality_debts_class_class( &quality, &moved_solution, the_probe, (*this_).layout_data );
             }
         }
 
         /* finish evaluating this solution */
-        geometry_rectangle_destroy( &solution_bounds );
+        layout_visible_classifier_destroy( &moved_solution );
+        U8_TRACE_INFO_FLT( "classifier solution debts", debts_of_current );
         if ( debts_of_current < debts_of_best )
         {
             debts_of_best = debts_of_current;
@@ -792,9 +763,8 @@ void pencil_classifier_2d_layouter_private_propose_embracing_order ( pencil_clas
 
         /* sort it into the array by the number of decendants: */
         /* the less descendants the earlier it shall be processed. */
-        const int err
-            = universal_array_index_sorter_insert( out_sorted, rel_idx, (double)from_descendant_count );
-        if ( 0 != err )
+        const u8_error_t err = universal_array_index_sorter_insert( out_sorted, rel_idx, (double)from_descendant_count );
+        if ( U8_ERROR_NONE != err )
         {
             U8_LOG_ERROR ( "universal_array_index_sorter_t list is full." );
         }
@@ -886,6 +856,15 @@ int pencil_classifier_2d_layouter_private_try_embrace_child( pencil_classifier_2
             /* cancel or commit */
             if ( ! illegal_overlap )
             {
+                /* trace */
+                {
+                    const data_visible_classifier_t *const visible_classifier
+                    = layout_visible_classifier_get_data_const( &probe_parent_layout );
+                    const data_classifier_t *const classifier
+                    = data_visible_classifier_get_classifier_const( visible_classifier );
+                    U8_TRACE_INFO_STR( "parent classifier:", data_classifier_get_name_const( classifier ) );
+                }
+
                 layout_visible_classifier_replacemove( from_classifier, &probe_parent_layout );
                 result_err = 0;
             }
@@ -979,9 +958,18 @@ void pencil_classifier_2d_layouter_move_and_embrace_children( pencil_classifier_
             = layout_visible_set_get_visible_classifier_ptr( (*this_).layout_data, classifier_idx );
 
         /* only if the classifier has children */
-        const uint32_t child_count = layout_visible_set_count_descendants ( (*this_).layout_data, the_classifier );
+        const uint32_t child_count = layout_visible_set_count_descendants( (*this_).layout_data, the_classifier );
         if ( child_count > 0 )
         {
+            /* trace */
+            {
+                const data_visible_classifier_t *const visible_classifier
+                    = layout_visible_classifier_get_data_const( the_classifier );
+                const data_classifier_t *const classifier
+                    = data_visible_classifier_get_classifier_const( visible_classifier );
+                U8_TRACE_INFO_STR( "parent classifier:", data_classifier_get_name_const( classifier ) );
+            }
+
             /* get envelope rectangle of all children */
             const geometry_rectangle_t children_envelope
                 = pencil_classifier_2d_layouter_private_calc_descendant_envelope( this_, the_classifier );
@@ -1034,9 +1022,10 @@ void pencil_classifier_2d_layouter_move_and_embrace_children( pencil_classifier_
                 const geometry_rectangle_t *const parent_new_space = layout_visible_classifier_get_space_const( the_classifier );
                 const double descendant_add_dx = geometry_rectangle_get_center_x( parent_new_space ) - geometry_rectangle_get_center_x( &children_envelope );
                 const double descendant_add_dy = geometry_rectangle_get_center_y( parent_new_space ) - geometry_rectangle_get_center_y( &children_envelope );
+                const geometry_offset_t offset = geometry_offset_new( descendant_add_dx, descendant_add_dy );
 
                 /* move the descendants */
-                pencil_classifier_2d_layouter_private_move_descendants( this_, the_classifier, descendant_add_dx, descendant_add_dy );
+                pencil_classifier_2d_layouter_private_move_descendants( this_, the_classifier, &offset );
             }
 
             /* cleanup */
@@ -1067,9 +1056,8 @@ void pencil_classifier_2d_layouter_private_propose_move_embrace_order ( pencil_c
         const uint32_t child_count = layout_visible_set_count_descendants ( (*this_).layout_data, the_classifier );
         lazy_move = child_count;
 
-        int insert_error;
-        insert_error = universal_array_index_sorter_insert( out_sorted, index, lazy_move );
-        if ( 0 != insert_error )
+        const u8_error_t insert_error = universal_array_index_sorter_insert( out_sorted, index, lazy_move );
+        if ( U8_ERROR_NONE != insert_error )
         {
             U8_LOG_WARNING( "not all rectangles are grown" );
         }
@@ -1080,7 +1068,7 @@ void pencil_classifier_2d_layouter_private_propose_move_embrace_order ( pencil_c
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
